@@ -14,9 +14,6 @@
 #include <KPluginFactory>
 #include <KSharedConfig>
 #include <KTextEditor/Document>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KTextEditor/InlineNoteInterface>
-#endif
 #include <KTextEditor/View>
 
 #include <QColor>
@@ -35,19 +32,11 @@ ColorPickerInlineNoteProvider::ColorPickerInlineNoteProvider(KTextEditor::Docume
 
     const auto views = m_doc->views();
     for (auto view : views) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         view->registerInlineNoteProvider(this);
-#else
-        qobject_cast<KTextEditor::InlineNoteInterface *>(view)->registerInlineNoteProvider(this);
-#endif
     }
 
     connect(m_doc, &KTextEditor::Document::viewCreated, this, [this](KTextEditor::Document *, KTextEditor::View *view) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         view->registerInlineNoteProvider(this);
-#else
-        qobject_cast<KTextEditor::InlineNoteInterface *>(view)->registerInlineNoteProvider(this);
-#endif
     });
 
     auto lineChanged = [this](const int line) {
@@ -103,20 +92,14 @@ ColorPickerInlineNoteProvider::~ColorPickerInlineNoteProvider()
     if (doc) {
         const auto views = m_doc->views();
         for (auto view : views) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             view->unregisterInlineNoteProvider(this);
-#else
-            if (auto ini = qobject_cast<KTextEditor::InlineNoteInterface *>(view)) {
-                ini->unregisterInlineNoteProvider(this);
-            }
-#endif
         }
     }
 }
 
 void ColorPickerInlineNoteProvider::updateColorMatchingCriteria()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "ColorPicker");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("ColorPicker"));
     m_matchHexLengths = config.readEntry("HexLengths", QList<int>{12, 9, 6, 3}).toVector();
     m_putPreviewAfterColor = config.readEntry("PreviewAfterColor", true);
     m_matchNamedColors = config.readEntry("NamedColors", false);
@@ -170,7 +153,7 @@ void ColorPickerInlineNoteProvider::updateNotes(int startLine, int endLine)
     }
 }
 
-QVector<int> ColorPickerInlineNoteProvider::inlineNotes(int line) const
+QList<int> ColorPickerInlineNoteProvider::inlineNotes(int line) const
 {
     if (!m_colorNoteIndices.contains(line)) {
         const QString lineText = m_doc->line(line);
@@ -207,12 +190,12 @@ QSize ColorPickerInlineNoteProvider::inlineNoteSize(const KTextEditor::InlineNot
     return QSize(note.lineHeight() - 1, note.lineHeight() - 1);
 }
 
-void ColorPickerInlineNoteProvider::paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter) const
+void ColorPickerInlineNoteProvider::paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter, Qt::LayoutDirection) const
 {
     const auto line = note.position().line();
     auto colorEnd = note.position().column();
 
-    const QVector<int> &colorNoteIndices = m_colorNoteIndices[line].colorNoteIndices;
+    const QList<int> &colorNoteIndices = m_colorNoteIndices[line].colorNoteIndices;
     // Since the colorNoteIndices are inserted in left-to-right (increasing) order in inlineNotes(), we can use binary search to find the index (or color note
     // number) for the line
     const int colorNoteNumber = std::lower_bound(colorNoteIndices.cbegin(), colorNoteIndices.cend(), colorEnd) - colorNoteIndices.cbegin();
@@ -243,7 +226,7 @@ void ColorPickerInlineNoteProvider::inlineNoteActivated(const KTextEditor::Inlin
     const auto line = note.position().line();
     auto colorEnd = note.position().column();
 
-    const QVector<int> &colorNoteIndices = m_colorNoteIndices[line].colorNoteIndices;
+    const QList<int> &colorNoteIndices = m_colorNoteIndices[line].colorNoteIndices;
     // Since the colorNoteIndices are inserted in left-to-right (increasing) order in inlineNotes, we can use binary search to find the index (or color note
     // number) for the line
     const int colorNoteNumber = std::lower_bound(colorNoteIndices.cbegin(), colorNoteIndices.cend(), colorEnd) - colorNoteIndices.cbegin();
