@@ -19,7 +19,6 @@
 #include <QList>
 #include <QRegularExpression>
 #include <QVariant>
-#include <QVector>
 
 class ColorPickerInlineNoteProvider : public KTextEditor::InlineNoteProvider
 {
@@ -32,9 +31,9 @@ public:
     // if startLine == -1, update all notes. endLine is optional
     void updateNotes(int startLine = -1, int endLine = -1);
 
-    QVector<int> inlineNotes(int line) const override;
+    QList<int> inlineNotes(int line) const override;
     QSize inlineNoteSize(const KTextEditor::InlineNote &note) const override;
-    void paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter) const override;
+    void paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter, Qt::LayoutDirection) const override;
     void inlineNoteActivated(const KTextEditor::InlineNote &note, Qt::MouseButtons buttons, const QPoint &globalPos) override;
 
 private:
@@ -46,15 +45,15 @@ private:
     struct ColorIndices {
         // When m_putPreviewAfterColor is true, otherColorIndices holds the starting color indices while colorNoteIndices holds the end color indices (and vice
         // versa) colorNoteIndices[i] corresponds to otherColorIndices[i]
-        QVector<int> colorNoteIndices;
-        QVector<int> otherColorIndices;
+        QList<int> colorNoteIndices;
+        QList<int> otherColorIndices;
     };
 
     // mutable is used here since InlineNoteProvider::inlineNotes() is const only, and we update the notes lazily (only when inlineNotes() is called)
     mutable QHash<int, ColorIndices> m_colorNoteIndices;
 
     QRegularExpression m_colorRegex;
-    QVector<int> m_matchHexLengths;
+    QList<int> m_matchHexLengths;
     bool m_putPreviewAfterColor;
     bool m_matchNamedColors;
 };
