@@ -59,7 +59,7 @@ QIcon blankIcon()
     return QIcon(pm);
 }
 
-static void makeToolUnique(KateExternalTool *tool, const QVector<KateExternalTool *> &tools)
+static void makeToolUnique(KateExternalTool *tool, const QList<KateExternalTool *> &tools)
 {
     // Ensure that tool->name is unique
     int i = 1;
@@ -109,7 +109,7 @@ static void makeToolUnique(KateExternalTool *tool, const QVector<KateExternalToo
     tool->cmdname = cmdname;
 }
 
-static KateExternalTool defaultTool(const QString &actionName, const QVector<KateExternalTool> &defaultTools)
+static KateExternalTool defaultTool(const QString &actionName, const QList<KateExternalTool> &defaultTools)
 {
     auto it = std::find_if(defaultTools.cbegin(), defaultTools.cend(), [actionName](const KateExternalTool &defaultTool) {
         return actionName == defaultTool.actionName;
@@ -117,7 +117,7 @@ static KateExternalTool defaultTool(const QString &actionName, const QVector<Kat
     return (it != defaultTools.cend()) ? *it : KateExternalTool();
 }
 
-static bool isDefaultTool(KateExternalTool *tool, const QVector<KateExternalTool> &defaultTools)
+static bool isDefaultTool(KateExternalTool *tool, const QList<KateExternalTool> &defaultTools)
 {
     return tool && !defaultTool(tool->actionName, defaultTools).actionName.isEmpty();
 }
@@ -302,7 +302,7 @@ void KateExternalToolsConfigWidget::apply()
     m_changed = false;
 
     KSharedConfigPtr config = m_plugin->config();
-    config->group("Global").writeEntry("firststart", false);
+    config->group(QStringLiteral("Global")).writeEntry("firststart", false);
     config->sync();
 
     m_plugin->removeTools(m_toolsToRemove);
@@ -341,7 +341,7 @@ bool KateExternalToolsConfigWidget::editTool(KateExternalTool *tool)
     KSharedConfigPtr config = m_plugin->config();
 
     KateExternalToolServiceEditor editor(tool, m_plugin, this);
-    KConfigGroup editorGroup = config->group("Editor");
+    KConfigGroup editorGroup = config->group(QStringLiteral("Editor"));
     editor.resize(editorGroup.readEntry("Size", QSize()));
 
     if (editor.exec() == QDialog::Accepted) {
