@@ -101,7 +101,7 @@ void KateFileBrowserConfigPage::apply()
 
     m_changed = false;
 
-    KConfigGroup config(KSharedConfig::openConfig(), "filebrowser");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("filebrowser"));
     QStringList l;
     ActionLBItem *aItem;
     const QList<QListWidgetItem *> list = acSel->selectedListWidget()->findItems(QStringLiteral("*"), Qt::MatchWildcard);
@@ -123,7 +123,7 @@ void KateFileBrowserConfigPage::reset()
 
 void KateFileBrowserConfigPage::init()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "filebrowser");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("filebrowser"));
     // toolbar
     QStringList l = config.readEntry("toolbar actions", QStringList());
     if (l.isEmpty()) { // default toolbar
@@ -158,11 +158,7 @@ void KateFileBrowserConfigPage::init()
         if (actionName == QLatin1String("bookmarks") || actionName == QLatin1String("sync_dir") || actionName == QLatin1String("configure")) {
             ac = fileBrowser->actionCollection()->action(actionName);
         } else {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
-            ac = fileBrowser->dirOperator()->actionCollection()->action(actionName);
-#else
             ac = fileBrowser->dirOperator()->action(KateFileBrowser::actionFromName(actionName));
-#endif
         }
 
         if (ac) {
