@@ -39,7 +39,7 @@ QObject *KateFileBrowserPlugin::createView(KTextEditor::MainWindow *mainWindow)
 void KateFileBrowserPlugin::viewDestroyed(QObject *view)
 {
     // do not access the view pointer, since it is partially destroyed already
-    m_views.removeAll(static_cast<KateFileBrowserPluginView *>(view));
+    m_views.removeAll(view);
 }
 
 int KateFileBrowserPlugin::configPages() const
@@ -73,7 +73,7 @@ KateFileBrowserPluginView::KateFileBrowserPluginView(KTextEditor::Plugin *plugin
 KateFileBrowserPluginView::~KateFileBrowserPluginView()
 {
     // cleanup, kill toolview + console
-    delete m_fileBrowser->parentWidget();
+    delete m_fileBrowser->parent();
 }
 
 void KateFileBrowserPluginView::readSessionConfig(const KConfigGroup &config)
