@@ -433,7 +433,7 @@ KateFileTreeModel::KateFileTreeModel(KTextEditor::MainWindow *mainWindow, QObjec
     initModel();
 
     // ensure palette change updates the colors properly
-    connect(qGuiApp, &QGuiApplication::paletteChanged, this, [this]() {
+    connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, [this]() {
         m_inactiveDocColor = KColorScheme(QPalette::Active).foreground(KColorScheme::InactiveText).color();
         updateBackgrounds(true);
     });
@@ -539,16 +539,7 @@ void KateFileTreeModel::connectDocument(const KTextEditor::Document *doc)
     connect(doc, &KTextEditor::Document::documentNameChanged, this, &KateFileTreeModel::documentNameChanged);
     connect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateFileTreeModel::documentNameChanged);
     connect(doc, &KTextEditor::Document::modifiedChanged, this, &KateFileTreeModel::documentModifiedChanged);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     connect(doc, &KTextEditor::Document::modifiedOnDisk, this, &KateFileTreeModel::documentModifiedOnDisc);
-#else
-    // clang-format off
-    connect(doc,
-            SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
-            this,
-            SLOT(documentModifiedOnDisc(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
-    // clang-format on
-#endif
 }
 
 QModelIndex KateFileTreeModel::docIndex(const KTextEditor::Document *doc) const
@@ -927,11 +918,7 @@ void KateFileTreeModel::documentModifiedChanged(KTextEditor::Document *doc)
     Q_EMIT dataChanged(idx, idx);
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 void KateFileTreeModel::documentModifiedOnDisc(KTextEditor::Document *doc, bool modified, KTextEditor::Document::ModifiedOnDiskReason reason)
-#else
-void KateFileTreeModel::documentModifiedOnDisc(KTextEditor::Document *doc, bool modified, KTextEditor::ModificationInterface::ModifiedOnDiskReason reason)
-#endif
 {
     Q_UNUSED(modified);
     auto it = m_docmap.find(doc);
@@ -947,7 +934,6 @@ void KateFileTreeModel::documentModifiedOnDisc(KTextEditor::Document *doc, bool
         item->clearFlag(ProxyItem::ModifiedExternally);
         item->clearFlag(ProxyItem::DeletedExternally);
     } else {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         if (reason == KTextEditor::Document::OnDiskDeleted) {
             item->setFlag(ProxyItem::DeletedExternally);
         } else if (reason == KTextEditor::Document::OnDiskModified) {
@@ -957,17 +943,6 @@ void KateFileTreeModel::documentModifiedOnDisc(KTextEditor::Document *doc, bool
             item->clearFlag(ProxyItem::ModifiedExternally);
             item->clearFlag(ProxyItem::DeletedExternally);
         }
-#else
-        if (reason == KTextEditor::ModificationInterface::OnDiskDeleted) {
-            item->setFlag(ProxyItem::DeletedExternally);
-        } else if (reason == KTextEditor::ModificationInterface::OnDiskModified) {
-            item->setFlag(ProxyItem::ModifiedExternally);
-        } else if (reason == KTextEditor::ModificationInterface::OnDiskCreated) {
-            // with out this, on "reload" we don't get the icons removed :(
-            item->clearFlag(ProxyItem::ModifiedExternally);
-            item->clearFlag(ProxyItem::DeletedExternally);
-        }
-#endif
     }
 
     setupIcon(item);
@@ -1053,8 +1028,8 @@ void KateFileTreeModel::updateBackgrounds(bool force)
 
     std::unordered_map<ProxyItem *, QBrush> oldBrushes = std::move(m_brushes);
 
-    const int hc = m_viewHistory.size();
-    const int ec = m_editHistory.size();
+    const int hc = (int)m_viewHistory.size();
+    const int ec = (int)m_editHistory.size();
     const QColor base = QPalette().color(QPalette::Base);
 
     for (const auto &[item, editViewCount] : helper) {
@@ -1124,16 +1099,7 @@ void KateFileTreeModel::documentClosed(KTextEditor::Document *doc)
     disconnect(doc, &KTextEditor::Document::documentNameChanged, this, &KateFileTreeModel::documentNameChanged);
     disconnect(doc, &KTextEditor::Document::documentUrlChanged, this, &KateFileTreeModel::documentNameChanged);
     disconnect(doc, &KTextEditor::Document::modifiedChanged, this, &KateFileTreeModel::documentModifiedChanged);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     disconnect(doc, &KTextEditor::Document::modifiedOnDisk, this, &KateFileTreeModel::documentModifiedOnDisc);
-#else
-    // clang-format off
-    disconnect(doc,
-                SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
-                this,
-                SLOT(documentModifiedOnDisc(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
-    // clang-format on
-#endif
 
     auto it = m_docmap.find(doc);
     if (it == m_docmap.end()) {
@@ -1501,7 +1467,7 @@ void KateFileTreeModel::resetHistory()
 
     for (ProxyItem *item : qAsConst(list)) {
         QModelIndex idx = createIndex(item->row(), 0, item);
-        dataChanged(idx, idx, QVector<int>(1, Qt::BackgroundRole));
+        dataChanged(idx, idx, QList<int>(1, Qt::BackgroundRole));
     }
 }
 
