@@ -49,10 +49,8 @@ KateFileTreePlugin::~KateFileTreePlugin()
 
 QObject *KateFileTreePlugin::createView(KTextEditor::MainWindow *mainWindow)
 {
-    KateFileTreePluginView *view = new KateFileTreePluginView(mainWindow, this);
-    connect(view, &KateFileTreePluginView::destroyed, this, &KateFileTreePlugin::viewDestroyed);
+    auto view = new KateFileTreePluginView(mainWindow, this);
     m_views.append(view);
-
     return view;
 }
 
@@ -231,10 +229,12 @@ KateFileTreePluginView::KateFileTreePluginView(KTextEditor::MainWindow *mainWind
 
 KateFileTreePluginView::~KateFileTreePluginView()
 {
+    m_plug->viewDestroyed(this);
+
     m_mainWindow->guiFactory()->removeClient(this);
 
     // clean up tree and toolview
-    delete m_fileTree->parentWidget();
+    delete m_fileTree->parent();
     // delete m_toolView;
     // and TreeModel
     delete m_documentModel;
@@ -274,11 +274,11 @@ void KateFileTreePluginView::setupActions()
      */
     if (KXmlGuiWindow *parentClient = qobject_cast<KXmlGuiWindow *>(m_mainWindow->window())) {
         bool newOrOpen = false;
-        if (auto a = parentClient->action("file_new")) {
+        if (auto a = parentClient->action(QStringLiteral("file_new"))) {
             m_toolbar->addAction(a);
             newOrOpen = true;
         }
-        if (auto a = parentClient->action("file_open")) {
+        if (auto a = parentClient->action(QStringLiteral("file_open"))) {
             m_toolbar->addAction(a);
             newOrOpen = true;
         }
