@@ -5,11 +5,11 @@
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
-#ifndef DEBUGVIEW_IFACE_H
-#define DEBUGVIEW_IFACE_H
+#pragma once
 
 #include <QObject>
 #include <QUrl>
+#include <ktexteditor/message.h>
 #include <optional>
 
 #include "configview.h"
@@ -141,8 +141,7 @@ Q_SIGNALS:
     void programEnded();
     void gdbEnded();
     void sourceFileNotFound(const QString &fileName);
+    void backendError(const QString &message, KTextEditor::Message::MessageType level);
 
     void debuggerCapabilitiesChanged();
 };
-
-#endif
