@@ -7,11 +7,10 @@
 #include "kategitblameplugin.h"
 #include "ktexteditor_utils.h"
 
+#include "hostprocess.h"
 #include <commitfilesview.h>
 #include <gitprocess.h>
 
-#include <algorithm>
-
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -20,19 +19,16 @@
 
 #include <KTextEditor/Document>
 #include <KTextEditor/Editor>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KTextEditor/InlineNoteInterface>
-#endif
 #include <KTextEditor/View>
 
 #include <QFileInfo>
-#include <QUrl>
-
 #include <QFontMetrics>
 #include <QKeySequence>
 #include <QLayout>
 #include <QPainter>
+#include <QUrl>
 #include <QVariant>
+#include <QtMath>
 
 static bool isUncomittedLine(const QByteArray &hash)
 {
@@ -47,27 +43,20 @@ GitBlameInlineNoteProvider::GitBlameInlineNoteProvider(KateGitBlamePluginView *p
 
 GitBlameInlineNoteProvider::~GitBlameInlineNoteProvider()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (m_pluginView->activeView()) {
         m_pluginView->activeView()->unregisterInlineNoteProvider(this);
     }
-#else
-    QPointer<KTextEditor::View> view = m_pluginView->activeView();
-    if (view) {
-        qobject_cast<KTextEditor::InlineNoteInterface *>(view)->unregisterInlineNoteProvider(this);
-    }
-#endif
 }
 
-QVector<int> GitBlameInlineNoteProvider::inlineNotes(int line) const
+QList<int> GitBlameInlineNoteProvider::inlineNotes(int line) const
 {
     if (!m_pluginView->hasBlameInfo()) {
-        return QVector<int>();
+        return QList<int>();
     }
 
     QPointer<KTextEditor::Document> doc = m_pluginView->activeDocument();
     if (!doc) {
-        return QVector<int>();
+        return QList<int>();
     }
 
     if (m_mode == KateGitBlameMode::None) {
@@ -77,9 +66,9 @@ QVector<int> GitBlameInlineNoteProvider::inlineNotes(int line) const
     int lineLen = doc->line(line).size();
     QPointer<KTextEditor::View> view = m_pluginView->activeView();
     if (view->cursorPosition().line() == line || m_mode == KateGitBlameMode::AllLines) {
-        return QVector<int>{lineLen + 4};
+        return QList<int>{lineLen + 4};
     }
-    return QVector<int>();
+    return QList<int>();
 }
 
 QSize GitBlameInlineNoteProvider::inlineNoteSize(const KTextEditor::InlineNote &note) const
@@ -87,7 +76,7 @@ QSize GitBlameInlineNoteProvider::inlineNoteSize(const KTextEditor::InlineNote &
     return QSize(note.lineHeight() * 50, note.lineHeight());
 }
 
-void GitBlameInlineNoteProvider::paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter) const
+void GitBlameInlineNoteProvider::paintInlineNote(const KTextEditor::InlineNote &note, QPainter &painter, Qt::LayoutDirection dir) const
 {
     QFont font = note.font();
     painter.setFont(font);
@@ -104,6 +93,26 @@ void GitBlameInlineNoteProvider::paintInlineNote(const KTextEditor::InlineNote &
         ? i18nc("git-blame information \"author: date \"", " %1: %2 ", info.authorName, date)
         : i18nc("git-blame information \"author: date: commit title \"", " %1: %2: %3 ", info.authorName, date, QString::fromUtf8(info.summary));
     QRect rectangle{0, 0, fm.horizontalAdvance(text), note.lineHeight()};
+    bool isRTL = false;
+    isRTL = dir == Qt::RightToLeft;
+
+    if (isRTL) {
+        const qreal horizontalTx = painter.worldTransform().m31();
+        // the amount of translation by x is from start of view (0,0) i.e., its the max
+        // amount of space we can use in rtl.
+        const int availableWidth = qFloor(horizontalTx);
+        const auto rectWidth = rectangle.width();
+        // the painter is translated to be at the end of line, move it left so that it is
+        // in front of the RTL line
+        const int moveBy = -(qAbs(rectWidth), qAbs(availableWidth));
+        rectangle.moveLeft(moveBy);
+        if (rectWidth > availableWidth) {
+            // reduce the width to available width
+            rectangle.setWidth(availableWidth);
+            // elide the text in the middle
+            text = painter.fontMetrics().elidedText(text, Qt::ElideMiddle, availableWidth);
+        }
+    }
 
     auto editor = KTextEditor::Editor::instance();
     auto color = QColor::fromRgba(editor->theme().textColor(KSyntaxHighlighting::Theme::Normal));
@@ -236,11 +245,7 @@ QPointer<KTextEditor::Document> KateGitBlamePluginView::activeDocument() const
 void KateGitBlamePluginView::startGitBlameForActiveView()
 {
     if (m_lastView) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         m_lastView->unregisterInlineNoteProvider(&m_inlineNoteProvider);
-#else
-        qobject_cast<KTextEditor::InlineNoteInterface *>(m_lastView)->unregisterInlineNoteProvider(&m_inlineNoteProvider);
-#endif
     }
 
     auto *view = m_mainWindow->activeView();
@@ -256,12 +261,7 @@ void KateGitBlamePluginView::startGitBlameForActiveView()
         return;
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     view->registerInlineNoteProvider(&m_inlineNoteProvider);
-#else
-    qobject_cast<KTextEditor::InlineNoteInterface *>(view)->registerInlineNoteProvider(&m_inlineNoteProvider);
-#endif
-
     startBlameProcess(url);
 }
 
@@ -519,9 +519,8 @@ const CommitInfo &KateGitBlamePluginView::blameInfo(int lineNr)
         return blameGetUpdateInfo(-1);
     }
 
-    int totalBlamedLines = m_blamedLines.size();
-
-    int adjustedLineNr = lineNr + m_lineOffset;
+    const int totalBlamedLines = (int)m_blamedLines.size();
+    const int adjustedLineNr = lineNr + m_lineOffset;
     const QByteArray lineText = activeDocument()->line(lineNr).toUtf8();
 
     if (adjustedLineNr >= 0 && adjustedLineNr < totalBlamedLines) {
