@@ -114,7 +114,7 @@ KateKonsolePluginView::~KateKonsolePluginView()
     m_plugin->mViews.removeAll(this);
 
     // cleanup, kill toolview + console
-    QWidget *toolview = m_console->parentWidget();
+    auto toolview = m_console->parent();
     delete m_console;
     delete toolview;
 }
@@ -189,7 +189,7 @@ void KateConsole::loadConsoleIfNeeded()
         return;
     }
 
-    if (!window() || !parentWidget()) {
+    if (!window() || !parent()) {
         return;
     }
     if (!window() || !isVisibleTo(window())) {
@@ -200,12 +200,7 @@ void KateConsole::loadConsoleIfNeeded()
         /**
          * get konsole part factory
          */
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        const QString konsolePart = QStringLiteral("konsolepart");
-#else
         const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
-#endif
-
         KPluginFactory *factory = KPluginFactory::loadFactory(konsolePart).plugin;
         if (!factory) {
             return;
@@ -269,7 +264,7 @@ void KateConsole::slotDestroyed()
     setFocusProxy(nullptr);
 
     // hide the dockwidget
-    if (parentWidget()) {
+    if (parent()) {
         m_mw->hideToolView(m_toolView);
     }
 }
@@ -372,12 +367,7 @@ KPluginFactory *KateConsole::pluginFactory()
     if (s_pluginFactory) {
         return s_pluginFactory;
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QString konsolePart = QStringLiteral("konsolepart");
-#else
     const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
-#endif
-
     return s_pluginFactory = KPluginFactory::loadFactory(konsolePart).plugin;
 }
 
@@ -437,7 +427,7 @@ void KateConsole::slotManualSync()
     slotSync();
 
     if (!m_part || !m_part->widget()->isVisible()) {
-        m_mw->showToolView(parentWidget());
+        m_mw->showToolView(qobject_cast<QWidget *>(parent()));
     }
 }
 
@@ -463,7 +453,7 @@ void KateConsole::slotRun()
         document->save();
     }
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "Konsole");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Konsole"));
     // The string that should be output to terminal, upon acceptance
     QString output_str;
     // Set prefix first
@@ -506,7 +496,7 @@ void KateConsole::slotToggleVisibility()
 {
     QAction *action = actionCollection()->action(QStringLiteral("katekonsole_tools_toggle_visibility"));
     if (!m_part || !m_part->widget()->isVisible()) {
-        m_mw->showToolView(parentWidget());
+        m_mw->showToolView(qobject_cast<QWidget *>(parent()));
         action->setText(i18nc("@action", "&Hide Terminal Panel"));
     } else {
         m_mw->hideToolView(m_toolView);
@@ -527,7 +517,7 @@ void KateConsole::focusChanged(QWidget *, QWidget *now)
 void KateConsole::slotToggleFocus()
 {
     if (!m_part) {
-        m_mw->showToolView(parentWidget());
+        m_mw->showToolView(qobject_cast<QWidget *>(parent()));
         return; // this shows and focuses the konsole
     }
 
@@ -537,8 +527,8 @@ void KateConsole::slotToggleFocus()
         }
     } else {
         // show the view if it is hidden
-        if (parentWidget()->isHidden()) {
-            m_mw->showToolView(parentWidget());
+        if (auto p = qobject_cast<QWidget *>(parent()); p->isHidden()) {
+            m_mw->showToolView(p);
         } else { // should focus the widget too!
             m_part->widget()->setFocus(Qt::OtherFocusReason);
         }
@@ -550,11 +540,11 @@ void KateConsole::readConfig()
     disconnect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotViewOrUrlChanged);
     disconnect(m_urlChangedConnection);
 
-    if (KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("AutoSyncronize", true)) {
+    if (KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("Konsole")).readEntry("AutoSyncronize", true)) {
         connect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotViewOrUrlChanged);
     }
 
-    if (KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("SetEditor", false)) {
+    if (KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("Konsole")).readEntry("SetEditor", false)) {
         qputenv("EDITOR", "kate -b");
     } else {
         setEditorEnv(m_plugin->previousEditorEnv());
@@ -563,11 +553,11 @@ void KateConsole::readConfig()
 
 void KateConsole::handleEsc(QEvent *e)
 {
-    if (!KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyBehaviour", true)) {
+    if (!KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("Konsole")).readEntry("KonsoleEscKeyBehaviour", true)) {
         return;
     }
 
-    QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
+    QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("Konsole")).readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
 
     if (!m_mw || !m_toolView || !e) {
         return;
@@ -676,7 +666,7 @@ QIcon KateKonsoleConfigPage::icon() const
 
 void KateKonsoleConfigPage::apply()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "Konsole");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Konsole"));
     config.writeEntry("AutoSyncronize", cbAutoSyncronize->isChecked());
     config.writeEntry("RemoveExtension", cbRemoveExtension->isChecked());
     config.writeEntry("RunPrefix", lePrefix->text());
@@ -689,7 +679,7 @@ void KateKonsoleConfigPage::apply()
 
 void KateKonsoleConfigPage::reset()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "Konsole");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Konsole"));
     cbAutoSyncronize->setChecked(config.readEntry("AutoSyncronize", true));
     cbRemoveExtension->setChecked(config.readEntry("RemoveExtension", false));
     lePrefix->setText(config.readEntry("RunPrefix", ""));
