@@ -29,12 +29,6 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/Message>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KTextEditor/CodeCompletionInterface>
-#include <KTextEditor/MovingInterface>
-#include <ktexteditor/configinterface.h>
-#include <ktexteditor/markinterface.h>
-#endif
 #include <KTextEditor/SessionConfigInterface>
 #include <KTextEditor/View>
 #include <KXMLGUIClient>
@@ -51,18 +45,19 @@
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QInputDialog>
-#include <QJsonDocument>
 #include <QJsonObject>
 #include <QKeyEvent>
 #include <QKeySequence>
 #include <QMenu>
+#include <QMessageBox>
 #include <QPainter>
 #include <QPlainTextEdit>
+#include <QPushButton>
 #include <QScopeGuard>
 #include <QSet>
 #include <QStandardItem>
+#include <QStringDecoder>
 #include <QStyledItemDelegate>
-#include <QTextCodec>
 #include <QTimer>
 #include <QTreeView>
 #include <unordered_map>
@@ -113,11 +108,7 @@ private:
     _kind m_value;
 };
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 static constexpr KTextEditor::Document::MarkTypes markType = KTextEditor::Document::markType31;
-#else
-static constexpr KTextEditor::MarkInterface::MarkTypes markType = KTextEditor::MarkInterface::markType31;
-#endif
 }
 
 KTextEditor::Document *findDocument(KTextEditor::MainWindow *mainWindow, const QUrl &url)
@@ -156,10 +147,9 @@ public:
         while (file.isOpen() && !file.atEnd()) {
             auto line = file.readLine();
             if (++lastLineNo == lineno) {
-                QTextCodec::ConverterState state;
-                QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-                QString text = codec->toUnicode(line.constData(), line.size(), &state);
-                if (state.invalidChars > 0) {
+                auto toUtf16 = QStringDecoder(QStringDecoder::Utf8);
+                QString text = toUtf16(line);
+                if (toUtf16.hasError()) {
                     text = QString::fromLatin1(line);
                 }
 
@@ -172,6 +162,16 @@ public:
     }
 };
 
+class CloseAllowedMessageBox : public QMessageBox
+{
+public:
+    using QMessageBox::QMessageBox;
+
+    void closeEvent(QCloseEvent *) override
+    {
+    }
+};
+
 class LocationTreeDelegate : public QStyledItemDelegate
 {
 public:
@@ -193,7 +193,7 @@ public:
         options.text = QString(); // clear old text
         options.widget->style()->drawControl(QStyle::CE_ItemViewItem, &options, painter, options.widget);
 
-        QVector<QTextLayout::FormatRange> formats;
+        QList<QTextLayout::FormatRange> formats;
         if (!index.parent().isValid()) {
             int lastSlash = text.lastIndexOf(QLatin1Char('/'));
             if (lastSlash != -1) {
@@ -259,39 +259,9 @@ public:
         if (mr) {
             mr->setRange(range);
         } else {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             mr.reset(doc->newMovingRange(range));
             connect(doc, &KTextEditor::Document::aboutToInvalidateMovingInterfaceContent, this, &CtrlHoverFeedback::clearMovingRange, Qt::UniqueConnection);
             connect(doc, &KTextEditor::Document::aboutToDeleteMovingInterfaceContent, this, &CtrlHoverFeedback::clearMovingRange, Qt::UniqueConnection);
-            connect(doc,
-                    SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document *)),
-                    this,
-                    SLOT(clear(KTextEditor::Document *)),
-                    Qt::UniqueConnection);
-            connect(doc,
-                    SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document *)),
-                    this,
-                    SLOT(clear(KTextEditor::Document *)),
-                    Qt::UniqueConnection);
-#else
-            auto miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
-            if (!miface) {
-                return;
-            }
-            mr.reset(miface->newMovingRange(range));
-            // clang-format off
-            connect(doc,
-                    SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)),
-                    this,
-                    SLOT(clearMovingRange(KTextEditor::Document*)),
-                    Qt::UniqueConnection);
-            connect(doc,
-                    SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)),
-                    this,
-                    SLOT(clearMovingRange(KTextEditor::Document*)),
-                    Qt::UniqueConnection);
-            // clang-format on
-#endif
         }
 
         static KTextEditor::Attribute::Ptr attr;
@@ -418,7 +388,7 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
     QPointer<QTreeView> m_typeDefTree;
 
     // views on which completions have been registered
-    QSet<KTextEditor::View *> m_completionViews;
+    QList<KTextEditor::View *> m_completionViews;
 
     // outstanding request
     LSPClientServer::RequestHandle m_handle;
@@ -428,11 +398,11 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
     // accept incoming applyEdit
     bool m_accept_edit = false;
     // characters to trigger format request
-    QVector<QChar> m_onTypeFormattingTriggers;
+    QList<QChar> m_onTypeFormattingTriggers;
 
     // ongoing workDoneProgress
     // list of (enhanced server token, progress begin)
-    QVector<std::pair<QString, LSPWorkDoneProgressParams>> m_workDoneProgress;
+    QList<std::pair<QString, LSPWorkDoneProgressParams>> m_workDoneProgress;
 
     CtrlHoverFeedback m_ctrlHoverFeedback = {};
 
@@ -505,6 +475,7 @@ public:
             onMessage(server, params);
         });
         connect(m_serverManager.get(), &LSPClientServerManager::serverWorkDoneProgress, this, &self_type::onWorkDoneProgress);
+        connect(m_serverManager.get(), &LSPClientServerManager::showMessageRequest, this, &self_type::showMessageRequest);
 
         m_findDef = actionCollection()->addAction(QStringLiteral("lspclient_find_definition"), this, &self_type::goToDefinition);
         m_findDef->setText(i18n("Go to Definition"));
@@ -532,14 +503,12 @@ public:
         m_triggerRename = actionCollection()->addAction(QStringLiteral("lspclient_rename"), this, &self_type::rename);
         m_triggerRename->setText(i18n("Rename"));
         actionCollection()->setDefaultShortcut(m_triggerRename, QKeySequence(Qt::Key_F2));
-#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5, 95, 0)
         m_expandSelection = actionCollection()->addAction(QStringLiteral("lspclient_expand_selection"), this, &self_type::expandSelection);
         m_expandSelection->setText(i18n("Expand Selection"));
         actionCollection()->setDefaultShortcut(m_expandSelection, QKeySequence(Qt::CTRL | Qt::Key_2));
         m_shrinkSelection = actionCollection()->addAction(QStringLiteral("lspclient_shrink_selection"), this, &self_type::shrinkSelection);
         m_shrinkSelection->setText(i18n("Shrink Selection"));
         actionCollection()->setDefaultShortcut(m_shrinkSelection, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_2));
-#endif
         m_switchSourceHeader = actionCollection()->addAction(QStringLiteral("lspclient_clangd_switchheader"), this, &self_type::clangdSwitchSourceHeader);
         m_switchSourceHeader->setText(i18n("Switch Source Header"));
         actionCollection()->setDefaultShortcut(m_switchSourceHeader, Qt::Key_F12);
@@ -719,7 +688,7 @@ public:
     KTextEditor::View *viewFromWidget(QWidget *widget)
     {
         if (widget) {
-            return qobject_cast<KTextEditor::View *>(widget->parentWidget());
+            return qobject_cast<KTextEditor::View *>(widget->parent());
         }
         return nullptr;
     }
@@ -776,24 +745,17 @@ public:
         }
 
         if (event->type() != QEvent::MouseButtonPress && event->type() != QEvent::MouseMove) {
+            // we are only concerned with mouse events for now :)
             return QObject::eventFilter(obj, event);
         }
 
         auto mouseEvent = static_cast<QMouseEvent *>(event);
-        // we are only concerned with mouse events for now :)
-        if (!mouseEvent) {
-            return false;
-        }
-
         const auto coords = viewInternal->mapTo(v, mouseEvent->pos());
         const auto cur = v->coordinatesToCursor(coords);
         // there isn't much we can do now, just bail out
-        if (!cur.isValid()) {
-            return false;
-        }
-
-        auto doc = v->document();
-        if (!doc) {
+        // if we have selection, and the click is on the selection ignore
+        // the event as we might block actions like ctrl-drag of text
+        if (!cur.isValid() || v->selectionRange().contains(cur)) {
             return false;
         }
 
@@ -809,6 +771,7 @@ public:
         // The user is hovering with Ctrl pressed
         else if (event->type() == QEvent::MouseMove) {
             if (mouseEvent->modifiers() == Qt::ControlModifier) {
+                auto doc = v->document();
                 auto range = doc->wordRangeAt(cur);
                 if (!range.isEmpty()) {
                     // check if we are in #include
@@ -843,11 +806,7 @@ public:
 
         // unregister all code-completion providers, else we might crash
         for (auto view : qAsConst(m_completionViews)) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             view->unregisterCompletionModel(m_completion.get());
-#else
-            qobject_cast<KTextEditor::CodeCompletionInterface *>(view)->unregisterCompletionModel(m_completion.get());
-#endif
         }
 
         clearAllLocationMarks();
@@ -947,7 +906,6 @@ public:
 
     static void clearMarks(KTextEditor::Document *doc, RangeCollection &ranges, DocumentCollection &docs, uint markType)
     {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         if (docs.contains(doc)) {
             const QHash<int, KTextEditor::Mark *> marks = doc->marks();
             QHashIterator<int, KTextEditor::Mark *> i(marks);
@@ -959,20 +917,6 @@ public:
             }
             docs.remove(doc);
         }
-#else
-        KTextEditor::MarkInterface *iface = docs.contains(doc) ? qobject_cast<KTextEditor::MarkInterface *>(doc) : nullptr;
-        if (iface) {
-            const QHash<int, KTextEditor::Mark *> marks = iface->marks();
-            QHashIterator<int, KTextEditor::Mark *> i(marks);
-            while (i.hasNext()) {
-                i.next();
-                if (i.value()->type & markType) {
-                    iface->removeMark(i.value()->line, markType);
-                }
-            }
-            docs.remove(doc);
-        }
-#endif
 
         for (auto it = ranges.find(doc); it != ranges.end() && it.key() == doc;) {
             delete it.value();
@@ -1074,27 +1018,15 @@ public:
 
         // highlight the range
         if (enabled && ranges && attr) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             KTextEditor::MovingRange *mr = doc->newMovingRange(range);
-#else
-            KTextEditor::MovingInterface *miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
-            Q_ASSERT(miface);
-            KTextEditor::MovingRange *mr = miface->newMovingRange(range);
-#endif
             mr->setZDepth(-90000.0); // Set the z-depth to slightly worse than the selection
             mr->setAttribute(attr);
             mr->setAttributeOnlyForViews(true);
             ranges->insert(doc, mr);
         }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         auto *iface = doc;
         KTextEditor::Document::MarkTypes markType = RangeData::markType;
-#else
-        KTextEditor::MarkInterfaceV2 *iface = qobject_cast<KTextEditor::MarkInterfaceV2 *>(doc);
-        Q_ASSERT(iface);
-        KTextEditor::MarkInterface::MarkTypes markType = RangeData::markType;
-#endif
         // add match mark for range
         switch (markType) {
         case RangeData::markType:
@@ -1111,24 +1043,8 @@ public:
             docs->insert(doc);
         }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         connect(doc, &KTextEditor::Document::aboutToInvalidateMovingInterfaceContent, this, &self_type::clearAllMarks, Qt::UniqueConnection);
         connect(doc, &KTextEditor::Document::aboutToDeleteMovingInterfaceContent, this, &self_type::clearAllMarks, Qt::UniqueConnection);
-#else
-        // ensure runtime match
-        // clang-format off
-        connect(doc,
-                SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)),
-                this,
-                SLOT(clearAllMarks(KTextEditor::Document*)),
-                Qt::UniqueConnection);
-        connect(doc,
-                SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)),
-                this,
-                SLOT(clearAllMarks(KTextEditor::Document*)),
-                Qt::UniqueConnection);
-        // clang-format on
-#endif
 
         // reload might save/restore marks before/after above signals, so let's clear before that
         connect(doc, &KTextEditor::Document::aboutToReload, this, &self_type::clearAllMarks, Qt::UniqueConnection);
@@ -1197,15 +1113,7 @@ public:
         if (!doc) {
             return;
         }
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         auto mr = doc->newMovingRange(location);
-#else
-        auto miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
-        if (!miface) {
-            return;
-        }
-        auto mr = miface->newMovingRange(location);
-#endif
         KTextEditor::Attribute::Ptr attr(new KTextEditor::Attribute);
         attr->setUnderlineStyle(QTextCharFormat::SingleUnderline);
         mr->setView(view);
@@ -1259,7 +1167,7 @@ public:
         std::shared_ptr<LSPClientRevisionSnapshot> snapshot(m_serverManager->snapshot(server.get()));
         auto h = [url, snapshot, executeCodeAction, this, data](const QList<LSPCodeAction> &actions) {
             // add actions below diagnostic item
-            QVector<DiagnosticFix> fixes;
+            QList<DiagnosticFix> fixes;
             for (const auto &action : actions) {
                 DiagnosticFix fix;
                 fix.fixTitle = action.title;
@@ -1412,7 +1320,7 @@ public:
         return url;
     }
 
-    void makeTree(const QVector<RangeItem> &locations, const LSPClientRevisionSnapshot *snapshot)
+    void makeTree(const QList<RangeItem> &locations, const LSPClientRevisionSnapshot *snapshot)
     {
         // group by url, assuming input is suitably sorted that way
         auto treeModel = new QStandardItemModel();
@@ -1589,7 +1497,7 @@ public:
                 showMessage(i18n("No results"), KTextEditor::Message::Information);
             } else {
                 // convert to helper type
-                QVector<RangeItem> ranges;
+                QList<RangeItem> ranges;
                 ranges.reserve(defs.size());
                 for (const auto &def : defs) {
                     ranges.push_back(itemConverter(def));
@@ -1761,7 +1669,7 @@ public:
             QTimer::singleShot(2000, this, [this] {
                 m_accept_edit = false;
             });
-            server->executeCommand(command.command, command.arguments);
+            server->executeCommand(command);
         }
     }
 
@@ -1841,15 +1749,8 @@ public:
 
         int tabSize = 4;
         bool insertSpaces = true;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         tabSize = document->configValue(QStringLiteral("tab-width")).toInt();
         insertSpaces = document->configValue(QStringLiteral("replace-tabs")).toBool();
-#else
-        auto cfgiface = qobject_cast<KTextEditor::ConfigInterface *>(document);
-        Q_ASSERT(cfgiface);
-        tabSize = cfgiface->configValue(QStringLiteral("tab-width")).toInt();
-        insertSpaces = cfgiface->configValue(QStringLiteral("replace-tabs")).toBool();
-#endif
 
         // sigh, no move initialization capture ...
         // (again) assuming reply ranges wrt revisions submitted at this time
@@ -1920,7 +1821,6 @@ public:
         delayCancelRequest(std::move(handle));
     }
 
-#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5, 95, 0)
     void expandSelection()
     {
         changeSelection(true);
@@ -1952,7 +1852,7 @@ public:
             }
 
             auto selections = activeView->selectionRanges();
-            QVector<KTextEditor::Range> ret;
+            QList<KTextEditor::Range> ret;
 
             for (int i = 0; i < cursors.size(); i++) {
                 const auto &lspSelectionRange = reply.at(i);
@@ -2003,7 +1903,6 @@ public:
 
         return LSPRange::invalid();
     }
-#endif
 
     void clangdSwitchSourceHeader()
     {
@@ -2031,12 +1930,11 @@ public:
         if (!server)
             return;
 
-        auto h = [this](const QJsonValue &reply) {
+        auto h = [this](const QString &reply) {
             auto view = m_mainWindow->openUrl(QUrl());
             if (view) {
-                QJsonDocument json(reply.toObject());
                 auto doc = view->document();
-                doc->setText(QString::fromUtf8(json.toJson()));
+                doc->setText(reply);
                 // position at top
                 view->setCursorPosition({0, 0});
                 // adjust mode
@@ -2463,7 +2361,7 @@ public:
         QAction *insertBefore = nullptr;
         // the name is used in KXMLGUI as object name
         // we want to insert before the cut action to ensure the KTE spelling menu is still on top
-        auto cutName = QString::fromLatin1(KStandardAction::name(KStandardAction::StandardAction::Cut));
+        const auto cutName = KStandardAction::name(KStandardAction::StandardAction::Cut);
 
         for (auto *act : menu->actions()) {
             if (act->objectName() == cutName) {
@@ -2487,7 +2385,7 @@ public:
     {
         // We need to remove our list or they will accumulated on next show event
         for (auto *act : m_contextMenuActions) {
-            act->parentWidget()->removeAction(act);
+            qobject_cast<QWidget *>(act->parent())->removeAction(act);
         }
     }
 
@@ -2506,7 +2404,7 @@ public:
 
     void viewDestroyed(QObject *view)
     {
-        m_completionViews.remove(static_cast<KTextEditor::View *>(view));
+        m_completionViews.removeAll(view);
     }
 
     void updateCompletion(KTextEditor::View *view, LSPClientServer *server)
@@ -2517,29 +2415,16 @@ public:
 
         bool registered = m_completionViews.contains(view);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        KTextEditor::CodeCompletionInterface *cci = qobject_cast<KTextEditor::CodeCompletionInterface *>(view);
-        Q_ASSERT(cci);
-#endif
-
         if (!registered && server && server->capabilities().completionProvider.provider) {
             qCInfo(LSPCLIENT) << "registering cci";
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             view->registerCompletionModel(m_completion.get());
-#else
-            cci->registerCompletionModel(m_completion.get());
-#endif
-            m_completionViews.insert(view);
+            m_completionViews.append(view);
         }
 
         if (registered && !server) {
             qCInfo(LSPCLIENT) << "unregistering cci";
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             view->unregisterCompletionModel(m_completion.get());
-#else
-            cci->unregisterCompletionModel(m_completion.get());
-#endif
-            m_completionViews.remove(view);
+            m_completionViews.removeAll(view);
         }
     }
 
@@ -2547,6 +2432,50 @@ public:
     {
         return m_symbolView->documentSymbolsModel();
     }
+
+    void showMessageRequest(const LSPShowMessageParams &message,
+                            const QList<LSPMessageRequestAction> &actions,
+                            const std::function<void()> chooseNothing,
+                            bool &handled)
+    {
+        if (handled) {
+            return;
+        }
+
+        handled = true;
+
+        CloseAllowedMessageBox box(m_mainWindow->window());
+        box.setWindowTitle(i18n("Question from LSP server"));
+        box.setText(message.message);
+        switch (message.type) {
+        case (LSPMessageType::Error):
+            box.setIcon(QMessageBox::Critical);
+            break;
+        case (LSPMessageType::Warning):
+            box.setIcon(QMessageBox::Warning);
+            break;
+        case (LSPMessageType::Info):
+            box.setIcon(QMessageBox::Question);
+            break;
+        case (LSPMessageType::Log):
+            box.setIcon(QMessageBox::Question);
+            break;
+        }
+
+        QMap<QAbstractButton *, std::function<void()>> onClick;
+        for (auto &action : actions) {
+            QString escaped = action.title;
+            escaped.replace(QLatin1Char('&'), QLatin1String("&&"));
+            QAbstractButton *button = box.addButton(escaped, QMessageBox::AcceptRole);
+            onClick[button] = action.choose;
+        }
+        box.exec();
+        if (actions.empty() || box.clickedButton() == nullptr) {
+            chooseNothing();
+        } else {
+            onClick[box.clickedButton()]();
+        }
+    }
 };
 
 QObject *LSPClientPluginView::new_(LSPClientPlugin *plugin, KTextEditor::MainWindow *mainWin, std::shared_ptr<LSPClientServerManager> manager)
