@@ -1,3 +1,10 @@
+/*
+    SPDX-FileCopyrightText: 2021 Waqar Ahmed <waqar.17a@gmail.com>
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#pragma once
+
 #include <QDialog>
 #include <QStandardItemModel>
 #include <QTreeView>
@@ -6,7 +13,7 @@ class BranchDeleteDialog : public QDialog
 {
     Q_OBJECT
 public:
-    BranchDeleteDialog(const QString &dotGitPath, QWidget *parent = nullptr);
+    explicit BranchDeleteDialog(const QString &dotGitPath, QWidget *parent = nullptr);
     QStringList branchesToDelete() const;
 
 private:
