@@ -12,6 +12,7 @@
 #include "diffparams.h"
 #include "gitcommitdialog.h"
 #include "gitstatusmodel.h"
+#include "hostprocess.h"
 #include "kateproject.h"
 #include "kateprojectplugin.h"
 #include "kateprojectpluginview.h"
@@ -1037,9 +1038,12 @@ void GitWidget::buildMenu(KActionCollection *ac)
     m_gitMenu->addAction(a);
 
     a = ac->addAction(QStringLiteral("git_show_commit"), this, [this] {
-        const QString hash = QInputDialog::getText(this, i18n("Show Commit"), i18n("Commit hash"));
-        const QString base = m_activeGitDirPath;
-        CommitView::openCommit(hash, base, m_mainWin);
+        bool ok = false;
+        const QString hash = QInputDialog::getText(this, i18n("Show Commit"), i18n("Commit hash"), QLineEdit::Normal, {}, &ok);
+        if (ok && !hash.isEmpty()) {
+            const QString base = m_activeGitDirPath;
+            CommitView::openCommit(hash, base, m_mainWin);
+        }
     });
     a->setIcon(QIcon::fromTheme(QStringLiteral("vcs-diff")));
     a->setText(i18n("Open Commit..."));
@@ -1124,11 +1128,7 @@ QAction *GitWidget::stashMenuAction(KActionCollection *ac, const QString &name,
 
 static KMessageBox::ButtonCode confirm(GitWidget *_this, const QString &text, const KGuiItem &confirmItem)
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     return KMessageBox::questionTwoActions(_this, text, {}, confirmItem, KStandardGuiItem::cancel(), {}, KMessageBox::Dangerous);
-#else
-    return KMessageBox::questionYesNo(_this, text, {}, confirmItem, KStandardGuiItem::cancel(), {}, KMessageBox::Dangerous);
-#endif
 }
 
 void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
@@ -1161,7 +1161,7 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
             return;
         }
 
-        const QVector<GitUtils::StatusItem> &items = untracked ? m_model->untrackedFiles() : m_model->changedFiles();
+        const QList<GitUtils::StatusItem> &items = untracked ? m_model->untrackedFiles() : m_model->changedFiles();
         QStringList files;
         files.reserve(items.size());
         std::transform(items.begin(), items.end(), std::back_inserter(files), [](const GitUtils::StatusItem &i) {
@@ -1172,20 +1172,12 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
             stage(files, treeItem == GitStatusModel::NodeUntrack);
         } else if (act == discardAct && !untracked) {
             auto ret = confirm(this, i18n("Are you sure you want to remove these files?"), KStandardGuiItem::remove());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (ret == KMessageBox::PrimaryAction) {
-#else
-            if (ret == KMessageBox::Yes) {
-#endif
                 discard(files);
             }
         } else if (act == discardAct && untracked) {
             auto ret = confirm(this, i18n("Are you sure you want to discard all changes?"), KStandardGuiItem::discard());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (ret == KMessageBox::PrimaryAction) {
-#else
-            if (ret == KMessageBox::Yes) {
-#endif
                 clean(files);
             }
         } else if (untracked && act == ignoreAct) {
@@ -1231,11 +1223,7 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
             return stage({file});
         } else if (act == discardAct && !untracked) {
             auto ret = confirm(this, i18n("Are you sure you want to discard the changes in this file?"), KStandardGuiItem::discard());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (ret == KMessageBox::PrimaryAction) {
-#else
-            if (ret == KMessageBox::Yes) {
-#endif
                 discard({file});
             }
         } else if (act == openAtHead && !untracked) {
@@ -1244,11 +1232,7 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
             showDiff(file, staged);
         } else if (act == discardAct && untracked) {
             auto ret = confirm(this, i18n("Are you sure you want to remove this file?"), KStandardGuiItem::remove());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (ret == KMessageBox::PrimaryAction) {
-#else
-            if (ret == KMessageBox::Yes) {
-#endif
                 clean({file});
             }
         } else if (act == launchDifftoolAct) {
@@ -1272,7 +1256,7 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
 
         // git reset -q HEAD --
         if (act == stage) {
-            const QVector<GitUtils::StatusItem> &items = m_model->stagedFiles();
+            const QList<GitUtils::StatusItem> &items = m_model->stagedFiles();
             QStringList files;
             files.reserve(items.size());
             std::transform(items.begin(), items.end(), std::back_inserter(files), [](const GitUtils::StatusItem &i) {
@@ -1344,20 +1328,12 @@ void GitWidget::selectedContextMenu(QContextMenuEvent *e)
         }
     } else if (selectionHasChangedItems && !selectionHasUntrackedItems && execAct == discardAct) {
         auto ret = confirm(this, i18n("Are you sure you want to discard the changes?"), KStandardGuiItem::discard());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (ret == KMessageBox::PrimaryAction) {
-#else
-        if (ret == KMessageBox::Yes) {
-#endif
             discard(files);
         }
     } else if (!selectionHasChangedItems && selectionHasUntrackedItems && execAct == removeAct) {
         auto ret = confirm(this, i18n("Are you sure you want to remove these untracked changes?"), KStandardGuiItem::remove());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (ret == KMessageBox::PrimaryAction) {
-#else
-        if (ret == KMessageBox::Yes) {
-#endif
             clean(files);
         }
     }
