@@ -485,7 +485,7 @@ bool KateProjectPlugin::restoreProjectsForSession() const
 
 void KateProjectPlugin::readConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "project");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("project"));
 
     const QStringList autorepository = config.readEntry("autorepository", DefaultConfig);
     m_autoGit = autorepository.contains(GitConfig);
@@ -509,7 +509,7 @@ void KateProjectPlugin::readConfig()
 
 void KateProjectPlugin::writeConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "project");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("project"));
     QStringList repos;
 
     if (m_autoGit) {
@@ -590,13 +590,8 @@ void KateProjectPlugin::registerVariables()
 void KateProjectPlugin::unregisterVariables()
 {
     auto editor = KTextEditor::Editor::instance();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    editor->unregisterVariableMatch(QStringLiteral("Project:Path"));
-    editor->unregisterVariableMatch(QStringLiteral("Project:NativePath"));
-#else
     editor->unregisterVariable(QStringLiteral("Project:Path"));
     editor->unregisterVariable(QStringLiteral("Project:NativePath"));
-#endif
 }
 
 void KateProjectPlugin::readSessionConfig(const KConfigGroup &config)
