@@ -20,9 +20,6 @@
 
 #include <KTextEditor/Command>
 #include <ktexteditor/application.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <ktexteditor/codecompletioninterface.h>
-#endif
 #include <ktexteditor/document.h>
 #include <ktexteditor/editor.h>
 #include <ktexteditor/view.h>
@@ -214,6 +211,10 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
     a->setText(i18n("Close Orphaned Projects"));
     a->setIcon(QIcon::fromTheme(QStringLiteral(PROJECTCLOSEICON)));
 
+    m_projectReloadAction = a = actionCollection()->addAction(QStringLiteral("project_reload"), this, SLOT(slotProjectReload()));
+    a->setText(i18n("Reload Project"));
+    a->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+
     m_gotoSymbolActionAppMenu = a = actionCollection()->addAction(KStandardAction::Goto, QStringLiteral("projects_goto_symbol"), this, SLOT(slotGotoSymbol()));
 
     auto chckbrAct = actionCollection()->addAction(QStringLiteral("checkout_branch"), this, [this] {
@@ -265,17 +266,10 @@ KateProjectPluginView::~KateProjectPluginView()
      * cleanup for all views
      */
     for (QObject *view : qAsConst(m_textViews)) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         KTextEditor::View *v = qobject_cast<KTextEditor::View *>(view);
         if (v) {
             v->unregisterCompletionModel(m_plugin->completion());
         }
-#else
-        KTextEditor::CodeCompletionInterface *cci = qobject_cast<KTextEditor::CodeCompletionInterface *>(view);
-        if (cci) {
-            cci->unregisterCompletionModel(m_plugin->completion());
-        }
-#endif
     }
 
     /**
@@ -635,14 +629,7 @@ void KateProjectPluginView::slotViewCreated(KTextEditor::View *view)
     /**
      * add completion model if possible
      */
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     view->registerCompletionModel(m_plugin->completion());
-#else
-    KTextEditor::CodeCompletionInterface *cci = qobject_cast<KTextEditor::CodeCompletionInterface *>(view);
-    if (cci) {
-        cci->registerCompletionModel(m_plugin->completion());
-    }
-#endif
 
     /**
      * remember for this view we need to cleanup!
