@@ -508,20 +508,8 @@ void PluginKateXMLToolsCompletionModel::assignDTD(PseudoDTD *dtd, KTextEditor::V
     m_docDtds.insert(view->document(), dtd);
 
     // TODO:perhaps for all views()?
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     view->registerCompletionModel(this);
     view->setAutomaticInvocationEnabled(true);
-#else
-    KTextEditor::CodeCompletionInterface *cci = qobject_cast<KTextEditor::CodeCompletionInterface *>(view);
-
-    if (cci) {
-        cci->registerCompletionModel(this);
-        cci->setAutomaticInvocationEnabled(true);
-        qDebug() << "PluginKateXMLToolsView: completion model registered";
-    } else {
-        qWarning() << "PluginKateXMLToolsView: completion interface unavailable";
-    }
-#endif
 }
 
 /**
