@@ -30,7 +30,7 @@
 #include <QRegularExpression>
 #include <QSessionManager>
 #include <QStandardPaths>
-#include <QTextCodec>
+#include <QStringDecoder>
 #include <QVariant>
 
 #include <qglobal.h>
@@ -42,16 +42,9 @@
 
 #if HAVE_X11
 
-#include "kwindowsystem_version.h"
-#if KWINDOWSYSTEM_VERSION > QT_VERSION_CHECK(5, 101, 0)
 #include <KX11Extras>
-#endif
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 #endif
 
 int main(int argc, char **argv)
@@ -85,7 +78,7 @@ int main(int argc, char **argv)
     /**
      * Connect application with translation catalogs, Kate & KWrite share the same one
      */
-    KLocalizedString::setApplicationDomain("kate");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kate"));
 
     /**
      * construct about data for Kate
@@ -331,13 +324,9 @@ int main(int argc, char **argv)
         if ((!force_new) && (serviceName.isEmpty())) {
             int desktopnumber = 0;
 #if HAVE_X11
-#if KWINDOWSYSTEM_VERSION > QT_VERSION_CHECK(5, 101, 0)
             if (KWindowSystem::isPlatformX11()) {
                 desktopnumber = KX11Extras::currentDesktop();
             }
-#else
-            desktopnumber = KWindowSystem::currentDesktop();
-#endif
 #endif
 
             for (int s = 0; s < kateServices.count(); s++) {
@@ -358,7 +347,7 @@ int main(int argc, char **argv)
                         if (answer.size() == 1) {
                             // special case: on all desktops! that is -1 aka NET::OnAllDesktops, see KWindowInfo::desktop() docs
                             const int sessionDesktopNumber = answer.at(0).toInt();
-                            if (sessionDesktopNumber == desktopnumber || sessionDesktopNumber == NET::OnAllDesktops) {
+                            if (sessionDesktopNumber == desktopnumber || sessionDesktopNumber == -1) {
                                 // stop searching. a candidate instance in the current desktop has been found
                                 foundRunningService = true;
                                 break;
@@ -433,11 +422,12 @@ int main(int argc, char **argv)
 
             if (parser.isSet(readStdInOption)) {
                 // set chosen codec
-                QTextCodec *codec = parser.isSet(useEncodingOption) ? QTextCodec::codecForName(parser.value(useEncodingOption).toUtf8()) : nullptr;
+                const QString codec_name = parser.isSet(QStringLiteral("encoding")) ? parser.value(QStringLiteral("encoding")) : QString();
 
                 QFile input;
                 input.open(stdin, QIODevice::ReadOnly);
-                QString text = codec ? codec->toUnicode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
+                auto decoder = QStringDecoder(codec_name.toUtf8().constData());
+                QString text = decoder.isValid() ? decoder.decode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
 
                 // normalize line endings, to e.g. catch issues with \r\n on Windows
                 text.replace(QRegularExpression(QStringLiteral("\r\n?")), QStringLiteral("\n"));
@@ -449,7 +439,7 @@ int main(int argc, char **argv)
 
                 QList<QVariant> dbusargs;
                 dbusargs.append(text);
-                dbusargs.append(codec ? QString::fromLatin1(codec->name()) : QString());
+                dbusargs.append(codec_name);
                 m.setArguments(dbusargs);
 
                 QDBusConnection::sessionBus().call(m);
