@@ -13,13 +13,9 @@
 #include "texthint/KateTextHintManager.h"
 
 #include <KActionCollection>
+#include <KActionMenu>
 #include <KTextEditor/Application>
 #include <KTextEditor/Editor>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KTextEditor/MarkInterface>
-#include <KTextEditor/MovingInterface>
-#include <KTextEditor/TextHintInterface>
-#endif
 
 #include <KColorScheme>
 #include <KXMLGUIFactory>
@@ -70,7 +66,7 @@ public:
         return {};
     }
 
-    void update(const QVector<DiagnosticsProvider *> &providerList)
+    void update(const QList<DiagnosticsProvider *> &providerList)
     {
         beginResetModel();
         m_providers.clear();
@@ -80,7 +76,7 @@ public:
     }
 
     DiagnosticsView *m_diagView;
-    QVector<DiagnosticsProvider *> m_providers;
+    QList<DiagnosticsProvider *> m_providers;
 };
 
 class DiagnosticsProxyModel final : public QSortFilterProxyModel
@@ -176,19 +172,11 @@ void DiagnosticsProvider::filterDiagnosticsViewTo(DiagnosticsProvider *filterTo)
     }
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 static constexpr KTextEditor::Document::MarkTypes markTypeDiagError = KTextEditor::Document::Error;
 static constexpr KTextEditor::Document::MarkTypes markTypeDiagWarning = KTextEditor::Document::Warning;
 static constexpr KTextEditor::Document::MarkTypes markTypeDiagOther = KTextEditor::Document::markType30;
 static constexpr KTextEditor::Document::MarkTypes markTypeDiagAll =
     KTextEditor::Document::MarkTypes(markTypeDiagError | markTypeDiagWarning | markTypeDiagOther);
-#else
-static constexpr KTextEditor::MarkInterface::MarkTypes markTypeDiagError = KTextEditor::MarkInterface::Error;
-static constexpr KTextEditor::MarkInterface::MarkTypes markTypeDiagWarning = KTextEditor::MarkInterface::Warning;
-static constexpr KTextEditor::MarkInterface::MarkTypes markTypeDiagOther = KTextEditor::MarkInterface::markType30;
-static constexpr KTextEditor::MarkInterface::MarkTypes markTypeDiagAll =
-    KTextEditor::MarkInterface::MarkTypes(markTypeDiagError | markTypeDiagWarning | markTypeDiagOther);
-#endif
 
 struct DiagModelIndex {
     int row;
@@ -223,7 +211,7 @@ public:
         options.text = QString(); // clear old text
         options.widget->style()->drawControl(QStyle::CE_ItemViewItem, &options, painter, options.widget);
 
-        QVector<QTextLayout::FormatRange> formats;
+        QList<QTextLayout::FormatRange> formats;
         int lastSlash = text.lastIndexOf(QLatin1Char('/'));
         if (lastSlash != -1) {
             QTextCharFormat fmt;
@@ -282,6 +270,9 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     , m_filterChangedTimer(new QTimer(this))
     , m_textHintProvider(new KateTextHintProvider(mainWindow, this))
 {
+    setComponentName(QStringLiteral("kate_diagnosticsview"), i18n("Diagnostics View"));
+    setXMLFile(QStringLiteral("ui.rc"));
+
     auto l = new QVBoxLayout(this);
     l->setContentsMargins({});
     setupDiagnosticViewToolbar(l);
@@ -319,16 +310,24 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     });
 
     auto *ac = actionCollection();
+
+    auto *diagMenu = new KActionMenu(i18nc("@action:inmenu Diagnostics View actions menu", "Diagnostics View"), this);
+    ac->addAction(QStringLiteral("tools_diagnosticsview"), diagMenu);
+
     auto *a = ac->addAction(QStringLiteral("kate_quick_fix"), this, &DiagnosticsView::quickFix);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Quick Fix"));
+    a->setIcon(QIcon::fromTheme(QStringLiteral("quickopen")));
     ac->setDefaultShortcut(a, QKeySequence((Qt::CTRL | Qt::Key_Period)));
 
     a = ac->addAction(QStringLiteral("goto_next_diagnostic"), this, &DiagnosticsView::nextItem);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Next Item"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
     ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Right);
 
     a = ac->addAction(QStringLiteral("goto_prev_diagnostic"), this, &DiagnosticsView::previousItem);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Previous Item"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
     ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_Left);
@@ -336,7 +335,9 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     a = ac->addAction(QStringLiteral("diagnostics_clear_filter"), this, [this]() {
         DiagnosticsView::filterViewTo(nullptr);
     });
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setText(i18n("Clear Diagnostics Filter"));
+    a->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-all")));
     ac->setDefaultShortcut(a, Qt::SHIFT | Qt::ALT | Qt::Key_C);
 
     m_posChangedTimer->setInterval(500);
@@ -355,7 +356,15 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
 
     connect(m_textHintProvider.get(), &KateTextHintProvider::textHintRequested, this, &DiagnosticsView::onTextHint);
     connect(m_mainWindow, &KTextEditor::MainWindow::unhandledShortcutOverride, this, &DiagnosticsView::handleEsc);
+
     mainWindow->guiFactory()->addClient(this);
+
+    // We don't want our shortcuts available in the whole mainwindow, as it can conflict
+    // with other KParts' shortcus (e.g. Konsole). The KateViewManager will be added to
+    // the asscioted widgets in KateMainWindow::setupDiagnosticsView(), after the view
+    // manager has been initialized.
+    ac->clearAssociatedWidgets();
+    ac->addAssociatedWidget(this);
 }
 
 DiagnosticsView *DiagnosticsView::instance(KTextEditor::MainWindow *mainWindow)
@@ -530,8 +539,8 @@ void DiagnosticsView::handleEsc(QEvent *event)
 
     auto keyEvent = static_cast<QKeyEvent *>(event);
     if (keyEvent && keyEvent->key() == Qt::Key_Escape && keyEvent->modifiers() == Qt::NoModifier) {
-        if (parentWidget() && parentWidget()->isVisible()) {
-            m_mainWindow->hideToolView(parentWidget());
+        if (auto p = qobject_cast<QWidget *>(parent()); p && p->isVisible()) {
+            m_mainWindow->hideToolView(p);
             event->accept();
         }
     }
@@ -610,7 +619,7 @@ static void fillItemRoles(QStandardItem *item, const QUrl &url, const KTextEdito
     item->setData(QVariant::fromValue(kind), DiagnosticModelRole::KindRole);
 }
 
-void DiagnosticsView::onFixesAvailable(const QVector<DiagnosticFix> &fixes, const QVariant &data)
+void DiagnosticsView::onFixesAvailable(const QList<DiagnosticFix> &fixes, const QVariant &data)
 {
     if (fixes.empty() || data.isNull()) {
         return;
@@ -650,7 +659,7 @@ void DiagnosticsView::onFixesAvailable(const QVector<DiagnosticFix> &fixes, cons
     }
 }
 
-void DiagnosticsView::showFixesInMenu(const QVector<DiagnosticFix> &fixes)
+void DiagnosticsView::showFixesInMenu(const QList<DiagnosticFix> &fixes)
 {
     auto av = m_mainWindow->activeView();
     if (av) {
@@ -687,7 +696,7 @@ void DiagnosticsView::quickFix()
 
     if (targetItem && targetItem->type() == DiagnosticItem_Diag) {
         if (static_cast<DiagnosticItem *>(targetItem)->hasFixes()) {
-            QVector<DiagnosticFix> fixes;
+            QList<DiagnosticFix> fixes;
             for (int i = 0; i < targetItem->rowCount(); ++i) {
                 auto item = targetItem->child(i);
                 if (item && item->type() == DiagnosticItem_Fix) {
@@ -773,9 +782,11 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
     }
     topItem->addProvider(provider);
 
+    QList<QStandardItem *> diagItems;
+    diagItems.reserve(diagnostics.diagnostics.size());
     for (const auto &diag : diagnostics.diagnostics) {
         auto item = new DiagnosticItem(diag);
-        topItem->appendRow(item);
+        diagItems.push_back(item);
         QString source;
         if (diag.source.length()) {
             source = QStringLiteral("[%1] ").arg(diag.source);
@@ -814,12 +825,12 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
             relatedItemMessage->setData(diagnosticsIcon(DiagnosticSeverity::Information), Qt::DecorationRole);
             item->appendRow(relatedItemMessage);
         }
-        m_diagnosticsTree->setExpanded(toProxyIndex(item->index()), true);
     }
+    topItem->appendRows(diagItems);
 
     // TODO perhaps add some custom delegate that only shows 1 line
     // and only the whole text when item selected ??
-    m_diagnosticsTree->setExpanded(toProxyIndex(topItem->index()), true);
+    m_diagnosticsTree->expandRecursively(toProxyIndex(topItem->index()), 1);
 
     // topItem might be removed after this
     updateDiagnosticsState(topItem);
@@ -843,7 +854,7 @@ static auto getProvider(QStandardItem *item)
     return item->data(DiagnosticModelRole::ProviderRole).value<DiagnosticsProvider *>();
 }
 
-void DiagnosticsView::clearDiagnosticsForStaleDocs(const QVector<QString> &filesToKeep, DiagnosticsProvider *provider)
+void DiagnosticsView::clearDiagnosticsForStaleDocs(const QList<QString> &filesToKeep, DiagnosticsProvider *provider)
 {
     auto all_diags_from_provider = [provider](DocumentDiagnosticItem *file) {
         if (file->rowCount() == 0) {
@@ -853,7 +864,7 @@ void DiagnosticsView::clearDiagnosticsForStaleDocs(const QVector<QString> &files
             return true;
         }
         if (!provider) {
-            const QVector<DiagnosticsProvider *> &providers = file->providers();
+            const QList<DiagnosticsProvider *> &providers = file->providers();
             return std::all_of(providers.begin(), providers.end(), [](DiagnosticsProvider *p) {
                 return !p->persistentDiagnostics();
             });
@@ -941,11 +952,7 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
     }
 
     KTextEditor::Attribute::Ptr attr;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     KTextEditor::Document::MarkTypes markType = markTypeDiagWarning;
-#else
-    KTextEditor::MarkInterface::MarkTypes markType = markTypeDiagWarning;
-#endif
 
     const auto kind = item->data(DiagnosticModelRole::KindRole).value<DiagnosticSeverity>();
     switch (kind) {
@@ -998,25 +1005,14 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
 
     // highlight the range
     if (attr && !range.isEmpty()) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         KTextEditor::MovingRange *mr = doc->newMovingRange(range);
-#else
-        KTextEditor::MovingInterface *miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
-        Q_ASSERT(miface);
-        KTextEditor::MovingRange *mr = miface->newMovingRange(range);
-#endif
         mr->setZDepth(-90000.0); // Set the z-depth to slightly worse than the selection
         mr->setAttribute(attr);
         mr->setAttributeOnlyForViews(true);
         m_diagnosticsRanges[doc].push_back(mr);
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     auto iface = doc;
-#else
-    KTextEditor::MarkInterfaceV2 *iface = qobject_cast<KTextEditor::MarkInterfaceV2 *>(doc);
-    Q_ASSERT(iface);
-#endif
     // add match mark for range
     switch (markType) {
     case markTypeDiagError:
@@ -1041,35 +1037,12 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
     m_diagnosticsMarks.insert(doc);
 
     // ensure runtime match
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     using Doc = KTextEditor::Document;
     connect(doc, &Doc::aboutToInvalidateMovingInterfaceContent, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
     connect(doc, &Doc::aboutToDeleteMovingInterfaceContent, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
     // reload might save/restore marks before/after above signals, so let's clear before that
     connect(doc, &Doc::aboutToReload, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
     connect(doc, &Doc::markClicked, this, &DiagnosticsView::onMarkClicked, Qt::UniqueConnection);
-#else
-    // clang-format off
-    connect(doc,
-            SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)),
-            this,
-            SLOT(clearAllMarks(KTextEditor::Document*)),
-            Qt::UniqueConnection);
-    connect(doc,
-            SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)),
-            this,
-            SLOT(clearAllMarks(KTextEditor::Document*)),
-            Qt::UniqueConnection);
-    // reload might save/restore marks before/after above signals, so let's clear before that
-    connect(doc, &KTextEditor::Document::aboutToReload, this, &DiagnosticsView::clearAllMarks, Qt::UniqueConnection);
-
-    connect(doc,
-            SIGNAL(markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)),
-            this,
-            SLOT(onMarkClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)),
-            Qt::UniqueConnection);
-    // clang-format on
-#endif
 }
 
 void DiagnosticsView::addMarksRec(KTextEditor::Document *doc, QStandardItem *item)
@@ -1096,7 +1069,6 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc)
 
 void DiagnosticsView::clearAllMarks(KTextEditor::Document *doc)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (m_diagnosticsMarks.contains(doc)) {
         const QHash<int, KTextEditor::Mark *> marks = doc->marks();
         for (auto mark : marks) {
@@ -1106,18 +1078,6 @@ void DiagnosticsView::clearAllMarks(KTextEditor::Document *doc)
         }
         m_diagnosticsMarks.remove(doc);
     }
-#else
-    KTextEditor::MarkInterface *iface = m_diagnosticsMarks.contains(doc) ? qobject_cast<KTextEditor::MarkInterface *>(doc) : nullptr;
-    if (iface) {
-        const QHash<int, KTextEditor::Mark *> marks = iface->marks();
-        for (auto mark : marks) {
-            if (mark->type & markTypeDiagAll) {
-                iface->removeMark(mark->line, markTypeDiagAll);
-            }
-        }
-        m_diagnosticsMarks.remove(doc);
-    }
-#endif
 
     auto it = m_diagnosticsRanges.find(doc);
     if (it != m_diagnosticsRanges.end()) {
@@ -1171,9 +1131,13 @@ void DiagnosticsView::updateDiagnosticsState(DocumentDiagnosticItem *&topItem)
         const auto ENABLED = Qt::ItemFlag::ItemIsEnabled;
         if ((flags & ENABLED) != !hide) {
             flags = hide ? (flags & ~ENABLED) : (flags | ENABLED);
-            item->setFlags(flags);
+            if (item->flags() != flags) {
+                item->setFlags(flags);
+            }
             const auto proxyIdx = m_proxy->mapFromSource(item->index());
-            m_diagnosticsTree->setRowHidden(proxyIdx.row(), proxyIdx.parent(), hide);
+            if (m_diagnosticsTree->isRowHidden(proxyIdx.row(), proxyIdx.parent()) != hide) {
+                m_diagnosticsTree->setRowHidden(proxyIdx.row(), proxyIdx.parent(), hide);
+            }
         }
         count += hide ? 0 : 1;
     }
@@ -1247,7 +1211,7 @@ void DiagnosticsView::onMarkClicked(KTextEditor::Document *document, KTextEditor
 
 void DiagnosticsView::showToolview(DiagnosticsProvider *filterTo)
 {
-    m_mainWindow->showToolView(parentWidget());
+    m_mainWindow->showToolView(qobject_cast<QWidget *>(parent()));
     filterViewTo(filterTo);
 }
 
@@ -1282,7 +1246,7 @@ bool DiagnosticsView::syncDiagnostics(KTextEditor::Document *document, int line,
         m_diagnosticsTree->setCurrentIndex(idx);
         m_diagnosticsTree->blockSignals(false);
         if (doShow) {
-            m_mainWindow->showToolView(parentWidget());
+            m_mainWindow->showToolView(qobject_cast<QWidget *>(parent()));
         }
     }
     return targetItem != nullptr;
@@ -1296,8 +1260,8 @@ void DiagnosticsView::updateDiagnosticsSuppression(DocumentDiagnosticItem *diagT
 
     auto &suppressions = diagTopItem->diagnosticSuppression;
     if (!suppressions || force) {
-        QVector<QJsonObject> providerSupressions;
-        const QVector<DiagnosticsProvider *> &providers = diagTopItem->providers();
+        QList<QJsonObject> providerSupressions;
+        const QList<DiagnosticsProvider *> &providers = diagTopItem->providers();
         for (auto p : providers) {
             auto suppressions = p->suppressions(doc);
             if (!suppressions.isEmpty()) {
@@ -1325,12 +1289,13 @@ void DiagnosticsView::onContextMenuRequested(const QPoint &pos)
 
     QModelIndex index = m_proxy->mapToSource(m_diagnosticsTree->currentIndex());
     if (QStandardItem *item = m_model.itemFromIndex(index)) {
+        auto diagText = index.data().toString();
+        menu->addAction(QIcon::fromTheme(QLatin1String("edit-copy")), i18n("Copy to Clipboard"), [diagText]() {
+            QClipboard *clipboard = QGuiApplication::clipboard();
+            clipboard->setText(diagText);
+        });
+
         if (item->type() == DiagnosticItem_Diag) {
-            auto diagText = index.data().toString();
-            menu->addAction(QIcon::fromTheme(QLatin1String("edit-copy")), i18n("Copy to Clipboard"), [diagText]() {
-                QClipboard *clipboard = QGuiApplication::clipboard();
-                clipboard->setText(diagText);
-            });
             menu->addSeparator();
             auto parent = index.parent();
             auto docDiagItem = static_cast<DocumentDiagnosticItem *>(m_model.itemFromIndex(parent));
@@ -1395,7 +1360,7 @@ void DiagnosticsView::onTextHint(KTextEditor::View *view, const KTextEditor::Cur
         int count = targetItem->rowCount();
         for (int i = 0; i < count; ++i) {
             auto item = targetItem->child(i);
-            result += QStringLiteral("  \n"); // markdown 2 spaces = newline
+            result += QStringLiteral("\n");
             result += item->text();
         }
         // but let's not get carried away too far
@@ -1406,7 +1371,7 @@ void DiagnosticsView::onTextHint(KTextEditor::View *view, const KTextEditor::Cur
         }
     }
 
-    m_textHintProvider->textHintAvailable(result.toHtmlEscaped(), TextHintMarkupKind::MarkDown, position);
+    m_textHintProvider->textHintAvailable(result, TextHintMarkupKind::PlainText, position);
 }
 
 void DiagnosticsView::onDocumentUrlChanged()
