@@ -51,7 +51,7 @@ int LineNumArea::lineNumAreaWidth() const
     return 13 + textEdit->fontMetrics().horizontalAdvance(u'9') * digits;
 }
 
-void LineNumArea::setLineNumData(QVector<int> leftLineNos, QVector<int> rightLineNos)
+void LineNumArea::setLineNumData(QList<int> leftLineNos, QList<int> rightLineNos)
 {
     m_lineToNumA = std::move(leftLineNos);
     m_lineToNumB = std::move(rightLineNos);
@@ -117,10 +117,10 @@ void LineNumArea::paintEvent(QPaintEvent *event)
     const QPen otherLines = m_otherLinesColor;
 
     QColor c = textEdit->addedColor();
-    c.setAlphaF(0.6);
+    c.setAlphaF(0.6f);
     const QPen added = c;
     c = textEdit->removedColor();
-    c.setAlphaF(0.6);
+    c.setAlphaF(0.6f);
     const QPen removed = c;
 
     LineNumColors colors{otherLines /*, currentLine*/, added, removed};
