@@ -147,11 +147,7 @@ std::pair<uint, uint> parseRange(const QString &range)
 {
     int commaPos = range.indexOf(QLatin1Char(','));
     if (commaPos > -1) {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-        return {range.midRef(0, commaPos).toInt(), range.midRef(commaPos + 1).toInt()};
-#else
         return {QStringView(range).sliced(0, commaPos).toInt(), QStringView(range).sliced(commaPos + 1).toInt()};
-#endif
     }
     return {range.toInt(), 1};
 }
@@ -526,9 +522,9 @@ VcsDiff VcsDiff::subDiff(const uint startLine, const uint endLine, DiffDirection
     return ret;
 }
 
-const QVector<VcsDiff::FilePair> VcsDiff::fileNames() const
+const QList<VcsDiff::FilePair> VcsDiff::fileNames() const
 {
-    QVector<VcsDiff::FilePair> ret;
+    QList<VcsDiff::FilePair> ret;
     VcsDiff::FilePair current;
     for (const auto &h : d->hunks) {
         // List each pair only once
