@@ -7,6 +7,7 @@
 #include "filehistorywidget.h"
 #include "commitfilesview.h"
 #include "diffparams.h"
+#include "hostprocess.h"
 #include "ktexteditor_utils.h"
 #include <bytearraysplitter.h>
 #include <gitprocess.h>
@@ -32,8 +33,6 @@
 #include <KTextEditor/Editor>
 #include <KTextEditor/MainWindow>
 
-#include <charconv>
-
 struct Commit {
     QByteArray hash;
     QString authorName;
@@ -106,7 +105,7 @@ public:
 
     int rowCount(const QModelIndex &) const override
     {
-        return m_rows.size();
+        return (int)m_rows.size();
     }
 
     QVariant data(const QModelIndex &index, int role) const override
@@ -129,7 +128,7 @@ public:
 
     void addCommits(std::vector<Commit> &&cmts)
     {
-        beginInsertRows(QModelIndex(), m_rows.size(), m_rows.size() + cmts.size() - 1);
+        beginInsertRows(QModelIndex(), (int)m_rows.size(), (int)m_rows.size() + (int)cmts.size() - 1);
         m_rows.insert(m_rows.end(), std::make_move_iterator(cmts.begin()), std::make_move_iterator(cmts.end()));
         endInsertRows();
     }
