@@ -20,29 +20,27 @@
 #include <KNetworkMounts>
 #include <KSharedConfig>
 
-// X11 startup handling
-#if __has_include(<KStartupInfo>)
-#include <KStartupInfo>
+// signal handler for SIGINT & SIGTERM
+#ifdef Q_OS_UNIX
+#include <KSignalHandler>
+#include <signal.h>
+#include <unistd.h>
 #endif
 
+// X11 startup handling
+#define HAVE_X11 __has_include(<KStartupInfo>)
+#if HAVE_X11
+#include <KStartupInfo>
 #include <KWindowInfo>
+#endif
 
 #ifdef WITH_KUSERFEEDBACK
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/ApplicationVersionSource>
 #include <KUserFeedbackQt6/PlatformInfoSource>
 #include <KUserFeedbackQt6/QtVersionSource>
 #include <KUserFeedbackQt6/ScreenInfoSource>
 #include <KUserFeedbackQt6/StartCountSource>
 #include <KUserFeedbackQt6/UsageTimeSource>
-#else
-#include <KUserFeedback/ApplicationVersionSource>
-#include <KUserFeedback/PlatformInfoSource>
-#include <KUserFeedback/QtVersionSource>
-#include <KUserFeedback/ScreenInfoSource>
-#include <KUserFeedback/StartCountSource>
-#include <KUserFeedback/UsageTimeSource>
-#endif
 #endif
 
 #include <QApplication>
@@ -54,11 +52,10 @@
 #include <QJsonDocument>
 #include <QLoggingCategory>
 #include <QRegularExpression>
-#include <QTextCodec>
+#include <QStringDecoder>
 #include <QTimer>
 #include <QUrlQuery>
 
-#include <signal_watcher.h>
 #include <urlinfo.h>
 
 #ifndef Q_OS_WIN
@@ -130,14 +127,6 @@ void KateApp::initPreApplicationCreation(bool detach)
     }
 #endif
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    /**
-     * enable high dpi support
-     */
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-#endif
-
     /**
      * allow fractional scaling
      * we only activate this on Windows, it seems to creates problems on unices
@@ -350,10 +339,13 @@ bool KateApp::init()
     /**
      * Set up signal handler for SIGINT and SIGTERM
      */
-    auto sigWatcher = new SignalWatcher(this);
-    connect(sigWatcher, &SignalWatcher::unixSignal, this, [this](SignalWatcher::Signal) {
-        printf("Shutting down...\n");
-        quit();
+    KSignalHandler::self()->watchSignal(SIGINT);
+    KSignalHandler::self()->watchSignal(SIGTERM);
+    connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
+        if (signal == SIGINT || signal == SIGTERM) {
+            printf("Shutting down...\n");
+            quit();
+        }
     });
 #endif
 
@@ -380,7 +372,7 @@ void KateApp::restoreKate()
     KConfig *sessionConfig = KConfigGui::sessionConfig();
 
     // activate again correct session!!!
-    QString lastSession(sessionConfig->group("General").readEntry("Last Session", QString()));
+    QString lastSession(sessionConfig->group(QStringLiteral("General")).readEntry("Last Session", QString()));
     sessionManager()->activateSession(lastSession, false, false);
 
     // plugins
@@ -417,7 +409,7 @@ bool KateApp::startupKate()
         } else if (!m_args.isSet(QStringLiteral("stdin")) && (m_args.positionalArguments().count() == 0)) { // only start session if no files specified
             // let the user choose session if possible
             if (!sessionManager()->chooseSession()) {
-#if __has_include(<KStartupInfo>)
+#if HAVE_X11
                 // we will exit kate now, notify the rest of the world we are done
                 KStartupInfo::appStarted();
 #endif
@@ -434,11 +426,10 @@ bool KateApp::startupKate()
         newMainWindow();
     }
 
-    QTextCodec *codec = m_args.isSet(QStringLiteral("encoding")) ? QTextCodec::codecForName(m_args.value(QStringLiteral("encoding")).toUtf8()) : nullptr;
     bool tempfileSet = m_args.isSet(QStringLiteral("tempfile"));
 
     KTextEditor::Document *doc = nullptr;
-    const QString codec_name = codec ? QString::fromLatin1(codec->name()) : QString();
+    const QString codec_name = m_args.isSet(QStringLiteral("encoding")) ? m_args.value(QStringLiteral("encoding")) : QString();
 
     const auto args = m_args.positionalArguments();
 
@@ -468,7 +459,8 @@ bool KateApp::startupKate()
     if (m_args.isSet(QStringLiteral("stdin"))) {
         QFile input;
         input.open(stdin, QIODevice::ReadOnly);
-        QString text = codec ? codec->toUnicode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
+        auto decoder = QStringDecoder(codec_name.toUtf8().constData());
+        QString text = decoder.isValid() ? decoder.decode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
 
         // normalize line endings, to e.g. catch issues with \r\n on Windows
         text.replace(QRegularExpression(QStringLiteral("\r\n?")), QStringLiteral("\n"));
@@ -527,6 +519,7 @@ KateStashManager *KateApp::stashManager()
 
 bool KateApp::isOnActivity(const QString &activity)
 {
+#if HAVE_X11
     for (const auto window : qAsConst(m_mainWindows)) {
         const KWindowInfo info(window->winId(), {}, NET::WM2Activities);
         const auto activities = info.activities();
@@ -537,6 +530,9 @@ bool KateApp::isOnActivity(const QString &activity)
     }
 
     return false;
+#else
+    return true;
+#endif
 }
 
 KTextEditor::Document *KateApp::openDocUrl(const QUrl &url, const QString &encoding, bool isTempFile, bool activateView, KTextEditor::Cursor c)
@@ -552,8 +548,6 @@ KTextEditor::Document *KateApp::openDocUrl(const QUrl &url, const QString &encod
         return nullptr;
     }
 
-    QTextCodec *codec = encoding.isEmpty() ? nullptr : QTextCodec::codecForName(encoding.toLatin1());
-
     // this file is no local dir, open it, else warn
     bool noDir = !url.isLocalFile() || KNetworkMounts::self()->isOptionEnabledForPath(url.toLocalFile(), KNetworkMounts::LowSideEffectsOptimizations)
         || !QFileInfo(url.toLocalFile()).isDir();
@@ -563,12 +557,7 @@ KTextEditor::Document *KateApp::openDocUrl(const QUrl &url, const QString &encod
     if (noDir) {
         KateDocumentInfo docInfo;
         docInfo.startCursor = c;
-        // open a normal file
-        if (codec) {
-            doc = mainWindow->viewManager()->openUrl(url, QString::fromLatin1(codec->name()), activateView, isTempFile, docInfo);
-        } else {
-            doc = mainWindow->viewManager()->openUrl(url, QString(), activateView, isTempFile, docInfo);
-        }
+        doc = mainWindow->viewManager()->openUrl(url, encoding, activateView, isTempFile, docInfo);
     } else {
         KMessageBox::error(mainWindow, i18n("The file '%1' could not be opened: it is not a normal file, it is a folder.", url.url()));
     }
@@ -736,7 +725,7 @@ bool KateApp::closeDocuments(const QList<KTextEditor::Document *> &documents)
 {
     bool shutdownKate =
         KateApp::self()->activeKateMainWindow()->modCloseAfterLast() && KateApp::self()->documentManager()->documentList().size() == documents.size();
-    bool success = m_docManager.closeDocumentList(documents);
+    bool success = m_docManager.closeDocumentList(documents, KateApp::self()->activeKateMainWindow());
 
     if (success && shutdownKate) {
         QTimer::singleShot(0, this, []() {
