@@ -10,11 +10,7 @@
 #include <ktexteditor/application.h>
 
 #ifdef WITH_KUSERFEEDBACK
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 #include "kateappadaptor.h"
@@ -327,7 +323,7 @@ public Q_SLOTS:
         QList<KTextEditor::MainWindow *> windows;
         windows.reserve(m_mainWindows.size());
 
-        for (const auto mainWindow : qAsConst(m_mainWindows)) {
+        for (const auto mainWindow : std::as_const(m_mainWindows)) {
             windows.push_back(mainWindow->wrapper());
         }
         return windows;
