@@ -18,11 +18,7 @@
 #include <KPageDialog>
 
 #ifdef WITH_KUSERFEEDBACK
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/FeedbackConfigWidget>
-#else
-#include <KUserFeedback/FeedbackConfigWidget>
-#endif
 #endif
 
 #include "ui_sessionconfigwidget.h"
@@ -84,16 +80,11 @@ private:
     // add page variant that ensures the page is wrapped into a QScrollArea
     KPageWidgetItem *addScrollablePage(QWidget *page, const QString &itemName);
 
-    void onSearchTextChanged();
-
 private:
     KateMainWindow *m_mainWindow;
 
     bool m_dataChanged = false;
 
-    QLineEdit *const m_searchLineEdit;
-    QTimer *const m_searchTimer;
-
     QComboBox *m_messageTypes = nullptr;
     QSpinBox *m_outputHistoryLimit = nullptr;
     QComboBox *m_mouseBackActions = nullptr;
@@ -123,7 +114,7 @@ private:
 
     QPointer<class QListView> m_sideBar;
     QSet<KPageWidgetItem *> m_allPages;
-    QVector<QWidget *> m_searchMatchOverlays;
+    QList<QWidget *> m_searchMatchOverlays;
 
 #ifdef WITH_KUSERFEEDBACK
     KUserFeedback::FeedbackConfigWidget *m_userFeedbackWidget = nullptr;
