@@ -9,7 +9,6 @@
 #include "katedocmanager.h"
 
 #include "kateapp.h"
-#include "katedebug.h"
 #include "katemainwindow.h"
 #include "katesavemodifieddialog.h"
 #include "kateviewmanager.h"
@@ -98,32 +97,16 @@ KTextEditor::Document *KateDocManager::createDoc(const KateDocumentInfo &docInfo
     KTextEditor::Document *doc = KTextEditor::Editor::instance()->createDocument(this);
 
     // turn off the editorpart's own modification dialog, we have our own one, too!
-    const KConfigGroup generalGroup(KSharedConfig::openConfig(), "General");
+    const KConfigGroup generalGroup(KSharedConfig::openConfig(), QStringLiteral("General"));
     bool ownModNotification = generalGroup.readEntry("Modified Notification", false);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     doc->setModifiedOnDiskWarning(!ownModNotification);
-#else
-    if (qobject_cast<KTextEditor::ModificationInterface *>(doc)) {
-        qobject_cast<KTextEditor::ModificationInterface *>(doc)->setModifiedOnDiskWarning(!ownModNotification);
-    }
-#endif
 
     m_docList.push_back(doc);
     m_docInfos.emplace(doc, docInfo);
 
     // connect internal signals...
     connect(doc, &KTextEditor::Document::modifiedChanged, this, &KateDocManager::slotModChanged1);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     connect(doc, &KTextEditor::Document::modifiedOnDisk, this, &KateDocManager::slotModifiedOnDisc);
-#else
-    // clang-format off
-    connect(doc,
-            SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
-            this,
-            SLOT(slotModifiedOnDisc(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
-    // clang-format on
-#endif
-
     connect(doc, &KParts::ReadOnlyPart::urlChanged, this, &KateDocManager::slotUrlChanged);
 
     // we have a new document, show it the world
@@ -231,7 +214,7 @@ bool KateDocManager::closeDocument(KTextEditor::Document *doc, bool closeUrl)
     return closeDocuments({doc}, closeUrl);
 }
 
-bool KateDocManager::closeDocumentList(const QList<KTextEditor::Document *> &documents)
+bool KateDocManager::closeDocumentList(const QList<KTextEditor::Document *> &documents, KateMainWindow *window)
 {
     std::vector<KTextEditor::Document *> modifiedDocuments;
     for (KTextEditor::Document *document : documents) {
@@ -240,7 +223,7 @@ bool KateDocManager::closeDocumentList(const QList<KTextEditor::Document *> &doc
         }
     }
 
-    if (!modifiedDocuments.empty() && !KateSaveModifiedDialog::queryClose(nullptr, modifiedDocuments)) {
+    if (!modifiedDocuments.empty() && !KateSaveModifiedDialog::queryClose(window, modifiedDocuments)) {
         return false;
     }
 
@@ -289,11 +272,7 @@ bool KateDocManager::queryCloseDocuments(KateMainWindow *w)
     const auto docCount = m_docList.size();
     for (KTextEditor::Document *doc : qAsConst(m_docList)) {
         if (doc->url().isEmpty() && doc->isModified()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             int msgres = KMessageBox::warningTwoActionsCancel(w,
-#else
-            int msgres = KMessageBox::warningYesNoCancel(w,
-#endif
                                                               i18n("<p>The document '%1' has been modified, but not saved.</p>"
                                                                    "<p>Do you want to save your changes or discard them?</p>",
                                                                    doc->documentName()),
@@ -305,11 +284,7 @@ bool KateDocManager::queryCloseDocuments(KateMainWindow *w)
                 return false;
             }
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (msgres == KMessageBox::PrimaryAction) {
-#else
-            if (msgres == KMessageBox::Yes) {
-#endif
                 const QUrl url = QFileDialog::getSaveFileUrl(w, i18n("Save As"));
                 if (!url.isEmpty()) {
                     if (!doc->saveAs(url)) {
@@ -382,7 +357,7 @@ void KateDocManager::closeOrphaned()
 
 void KateDocManager::saveDocumentList(KConfig *config)
 {
-    KConfigGroup openDocGroup(config, "Open Documents");
+    KConfigGroup openDocGroup(config, QStringLiteral("Open Documents"));
 
     openDocGroup.writeEntry("Count", (int)m_docList.size());
 
@@ -398,7 +373,7 @@ void KateDocManager::saveDocumentList(KConfig *config)
 
 void KateDocManager::restoreDocumentList(KConfig *config)
 {
-    KConfigGroup openDocGroup(config, "Open Documents");
+    KConfigGroup openDocGroup(config, QStringLiteral("Open Documents"));
     unsigned int count = openDocGroup.readEntry("Count", 0);
 
     if (count == 0) {
@@ -427,11 +402,7 @@ void KateDocManager::restoreDocumentList(KConfig *config)
     }
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 void KateDocManager::slotModifiedOnDisc(KTextEditor::Document *doc, bool b, KTextEditor::Document::ModifiedOnDiskReason reason)
-#else
-void KateDocManager::slotModifiedOnDisc(KTextEditor::Document *doc, bool b, KTextEditor::ModificationInterface::ModifiedOnDiskReason reason)
-#endif
 {
     auto it = m_docInfos.find(doc);
     if (it != m_docInfos.end()) {
@@ -471,8 +442,6 @@ bool KateDocManager::loadMetaInfos(KTextEditor::Document *doc, const QUrl &url)
             urlGroup.deleteGroup();
             ok = false;
         }
-
-        m_metaInfos.sync();
     }
 
     return ok && doc->url() == url;
@@ -491,6 +460,8 @@ void KateDocManager::saveMetaInfos(const QList<KTextEditor::Document *> &documen
         return;
     }
 
+    const QSet<QString> flags{QStringLiteral("SkipUrl")};
+
     /**
      * store meta info for all non-modified documents which have some checksum
      */
@@ -508,21 +479,22 @@ void KateDocManager::saveMetaInfos(const QList<KTextEditor::Document *> &documen
             /**
              * write the group with checksum and time
              */
-            KConfigGroup urlGroup(&m_metaInfos, doc->url().toString());
-            urlGroup.writeEntry("Checksum", QString::fromLatin1(checksum));
-            urlGroup.writeEntry("Time", now);
+            const QString url = doc->url().toString();
+            KConfigGroup urlGroup(&m_metaInfos, url);
 
             /**
              * write document session config
              */
-            doc->writeSessionConfig(urlGroup);
+            doc->writeSessionConfig(urlGroup, flags);
+            if (!urlGroup.keyList().isEmpty()) {
+                urlGroup.writeEntry("URL", url);
+                urlGroup.writeEntry("Checksum", QString::fromLatin1(checksum));
+                urlGroup.writeEntry("Time", now);
+            } else {
+                urlGroup.deleteGroup();
+            }
         }
     }
-
-    /**
-     * sync to not loose data
-     */
-    m_metaInfos.sync();
 }
 
 void KateDocManager::slotModChanged(KTextEditor::Document *doc)
