@@ -9,17 +9,12 @@
 
 // BEGIN Includes
 #include "katemainwindow.h"
-#include "kconfigwidgets_version.h"
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 107, 0)
 #include <KColorSchemeMenu>
-#endif
 
 #include "diagnostics/diagnosticview.h"
 #include "filehistorywidget.h"
 #include "kateapp.h"
 #include "kateconfigdialog.h"
-#include "kateconfigplugindialogpage.h"
-#include "katedebug.h"
 #include "katedocmanager.h"
 #include "katefileactions.h"
 #include "katemwmodonhddialog.h"
@@ -73,8 +68,6 @@
 #include <QTimer>
 #include <QToolButton>
 
-#include "diffwidget.h"
-
 #include <ktexteditor/sessionconfiginterface.h>
 
 // END
@@ -83,7 +76,7 @@
 static bool winClosesDocuments()
 {
     const auto config = KSharedConfig::openConfig();
-    const KConfigGroup cgGeneral(config, "General");
+    const KConfigGroup cgGeneral(config, QStringLiteral("General"));
     return cgGeneral.readEntry("Close documents with window", true);
 }
 
@@ -126,7 +119,7 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
     setupImportantActions();
 
     // setup the most important widgets
-    setupMainWindow(sconfig);
+    setupMainWindow();
 
     // setup the actions
     setupActions();
@@ -135,6 +128,10 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
     setXMLFile(QStringLiteral("kateui.rc"));
     createShellGUI(true);
 
+    // Has to be after the setXMLFile() call above, so that m_diagView's actions are
+    // merged after the Tools menu has been populated with the default actions
+    setupDiagnosticsView(sconfig);
+
     // qCDebug(LOG_KATE) << "****************************************************************************" << sconfig;
 
     // register mainwindow in app
@@ -163,7 +160,7 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
 
     finishRestore();
 
-    m_fileOpenRecent->loadEntries(KConfigGroup(sconfig, "Recent Files"));
+    m_fileOpenRecent->loadEntries(KConfigGroup(sconfig, QStringLiteral("Recent Files")));
 
     setAcceptDrops(true);
 
@@ -177,6 +174,8 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
     // Hence, we have to take care of the menu bar here
     toggleShowMenuBar(false);
 
+    ensureHamburgerBarSize();
+
     // trigger proper focus restore
     m_viewManager->triggerActiveViewFocus();
 }
@@ -184,7 +183,7 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
 KateMainWindow::~KateMainWindow()
 {
     // first, save our fallback window size ;)
-    KConfigGroup cfg(KSharedConfig::openConfig(), "MainWindow");
+    KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
     KWindowConfig::saveWindowSize(windowHandle(), cfg);
 
     // save other options ;=)
@@ -257,12 +256,7 @@ void KateMainWindow::setupImportantActions()
 
     // Load themes
     KColorSchemeManager *manager = new KColorSchemeManager(this);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 107, 0)
-    const QString colorScheme = KConfigGroup(KSharedConfig::openConfig(), "UiSettings").readEntry("ColorScheme", QString());
-    auto *colorSelectionMenu = manager->createSchemeSelectionMenu(colorScheme, this);
-#else
     auto *colorSelectionMenu = KColorSchemeMenu::createMenu(manager, this);
-#endif
     colorSelectionMenu->menu()->setTitle(i18n("&Window Color Scheme"));
     actionCollection()->addAction(QStringLiteral("colorscheme_menu"), colorSelectionMenu);
 
@@ -292,7 +286,7 @@ void KateMainWindow::setupImportantActions()
     hamburgerMenu->setShowMenuBarAction(m_paShowMenuBar);
 }
 
-void KateMainWindow::setupMainWindow(KConfig *sconfig)
+void KateMainWindow::setupMainWindow()
 {
     m_viewManager = new KateViewManager(centralWidget(), this);
     centralWidget()->layout()->addWidget(m_viewManager);
@@ -317,9 +311,6 @@ void KateMainWindow::setupMainWindow(KConfig *sconfig)
                                       QIcon::fromTheme(QStringLiteral("output_win")),
                                       i18n("Output"));
     m_outputView = new KateOutputView(this, m_toolViewOutput);
-
-    m_diagView = DiagnosticsView::instance(wrapper());
-    m_diagView->readSessionConfig(KConfigGroup(sconfig, "Kate Diagnostics"));
 }
 
 void KateMainWindow::setupActions()
@@ -555,6 +546,40 @@ void KateMainWindow::setupActions()
     });
 }
 
+void KateMainWindow::setupDiagnosticsView(KConfig *sconfig)
+{
+    m_diagView = DiagnosticsView::instance(wrapper());
+    m_diagView->readSessionConfig(KConfigGroup(sconfig, QStringLiteral("Kate Diagnostics")));
+    // See comment in DiagnosticsView::DiagnosticsView()
+    m_diagView->actionCollection()->addAssociatedWidget(m_viewManager);
+}
+
+void KateMainWindow::ensureHamburgerBarSize()
+{
+    // Ensure the hamburger menu never gets pushed into the toolbar overflow
+    // by setting a minimum size on the bar based on the button's size.
+    if (auto *hamburgerBar = toolBar(QStringLiteral("hamburgerBar"))) {
+        auto *hamburgerMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
+        if (auto *hamburgerButton = hamburgerBar->widgetForAction(hamburgerMenu)) {
+            int neededButtonWidth = hamburgerButton->minimumSizeHint().width();
+            // Add toolbar margins.
+            const QMargins combinedMargins = hamburgerBar->contentsMargins() + hamburgerBar->layout()->contentsMargins();
+            neededButtonWidth += combinedMargins.left();
+            neededButtonWidth += combinedMargins.right();
+
+            // The dynamic spacer is also an action leading to spacing being added.
+            // Not observable with Breeze but e.g. Fusion style has toolbar button spacing.
+            if (hamburgerBar->actions().count() > 1) {
+                neededButtonWidth += hamburgerBar->layout()->spacing();
+            }
+
+            QSize minimumSize = hamburgerBar->minimumSize();
+            minimumSize.setWidth(std::max(minimumSize.width(), neededButtonWidth));
+            hamburgerBar->setMinimumSize(minimumSize);
+        }
+    }
+}
+
 void KateMainWindow::slotDocumentCloseAll()
 {
     if (!KateApp::self()->documentManager()->documentList().empty()
@@ -711,10 +736,10 @@ KateMainWindow *KateMainWindow::newWindow() const
 
 void KateMainWindow::slotEditToolbars()
 {
-    KConfigGroup cfg(KSharedConfig::openConfig(), "MainWindow");
+    KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
     saveMainWindowSettings(cfg);
 
-    KEditToolBar dlg(factory());
+    KEditToolBar dlg(factory(), this);
 
     connect(&dlg, &KEditToolBar::newToolBarConfig, this, &KateMainWindow::slotNewToolbarConfig);
     dlg.exec();
@@ -733,7 +758,7 @@ void KateMainWindow::reloadXmlGui()
 
 void KateMainWindow::slotNewToolbarConfig()
 {
-    applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), "MainWindow"));
+    applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("MainWindow")));
 
     // we need to reload all View's XML Gui from disk to ensure toolbar
     // changes are applied to all views.
@@ -759,7 +784,7 @@ void KateMainWindow::readOptions()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    const KConfigGroup generalGroup(config, "General");
+    const KConfigGroup generalGroup(config, QStringLiteral("General"));
     m_modNotification = generalGroup.readEntry("Modified Notification", false);
     m_modCloseAfterLast = generalGroup.readEntry("Close After Last", KateApp::isKWrite());
     KateApp::self()->documentManager()->setSaveMetaInfos(generalGroup.readEntry("Save Meta Infos", true));
@@ -791,7 +816,7 @@ void KateMainWindow::saveOptions()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    KConfigGroup generalGroup(config, "General");
+    KConfigGroup generalGroup(config, QStringLiteral("General"));
 
     generalGroup.writeEntry("Save Meta Infos", KateApp::self()->documentManager()->getSaveMetaInfos());
 
@@ -865,11 +890,11 @@ void KateMainWindow::slotUpdateActionsNeedingUrl()
     auto &&view = viewManager()->activeView();
     const bool hasUrl = view && !view->document()->url().isEmpty();
 
-    action("file_copy_filepath")->setEnabled(hasUrl);
-    action("file_open_containing_folder")->setEnabled(hasUrl);
-    action("file_rename")->setEnabled(hasUrl);
-    action("file_delete")->setEnabled(hasUrl);
-    action("file_properties")->setEnabled(hasUrl);
+    action(QStringLiteral("file_copy_filepath"))->setEnabled(hasUrl);
+    action(QStringLiteral("file_open_containing_folder"))->setEnabled(hasUrl);
+    action(QStringLiteral("file_rename"))->setEnabled(hasUrl);
+    action(QStringLiteral("file_delete"))->setEnabled(hasUrl);
+    action(QStringLiteral("file_properties"))->setEnabled(hasUrl);
     documentOpenWith->setEnabled(hasUrl);
 }
 
@@ -904,9 +929,8 @@ void KateMainWindow::slotDropEvent(QDropEvent *event)
         // view where it was dropped
         KTextEditor::View *kVsender = qobject_cast<KTextEditor::View *>(QObject::sender());
         if (kVsender != nullptr) {
-            QWidget *parent = kVsender->parentWidget();
-            if (parent != nullptr) {
-                KateViewSpace *vs = qobject_cast<KateViewSpace *>(parent->parentWidget());
+            if (auto parent = kVsender->parent()) {
+                KateViewSpace *vs = qobject_cast<KateViewSpace *>(parent->parent());
                 if (vs != nullptr) {
                     m_viewManager->setActiveSpace(vs);
                 }
@@ -918,22 +942,14 @@ void KateMainWindow::slotDropEvent(QDropEvent *event)
             KFileItem kitem(url);
             kitem.setDelayedMimeTypes(true);
             if (kitem.isDir()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 if (KMessageBox::questionTwoActions(this,
-#else
-                if (KMessageBox::questionYesNo(this,
-#endif
                                                     i18n("You dropped the directory %1 into Kate. "
                                                          "Do you want to open all files contained in it?",
                                                          url.url()),
                                                     i18nc("@title:window", "Open Files Recursively"),
                                                     KGuiItem(i18nc("@action:button", "Open All Files"), QStringLiteral("document-open")),
                                                     KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                     == KMessageBox::PrimaryAction) {
-#else
-                    == KMessageBox::Yes) {
-#endif
                     KIO::ListJob *list_job = KIO::listRecursive(url, KIO::DefaultFlags, false);
                     connect(list_job, &KIO::ListJob::entries, this, &KateMainWindow::slotListRecursiveEntries);
                 }
@@ -1085,7 +1101,7 @@ void KateMainWindow::slotFullScreen(bool t)
 bool KateMainWindow::showModOnDiskPrompt(ModOnDiskMode mode)
 {
     const auto documents = KateApp::self()->documentManager()->documentList();
-    QVector<KTextEditor::Document *> list;
+    QList<KTextEditor::Document *> list;
     list.reserve(documents.size());
     for (auto doc : documents) {
         if (KateApp::self()->documentManager()->documentInfo(doc)->modifiedOnDisc && (doc->isModified() || mode == PromptAll)) {
@@ -1141,17 +1157,7 @@ void KateMainWindow::updateCaption(KTextEditor::Document *doc)
         c = m_viewManager->activeView()->document()->documentName();
     } else {
         // we want some filename @ folder output to have chance to keep important stuff even on elide
-        if (url.isLocalFile()) {
-            // perhaps shorten the path
-            const QString homePath = QDir::homePath();
-            QString path = url.toString(QUrl::RemoveFilename | QUrl::PreferLocalFile | QUrl::StripTrailingSlash);
-            if (path.startsWith(homePath)) {
-                path = QLatin1String("~") + path.right(path.length() - homePath.length());
-            }
-            c = url.fileName() + QStringLiteral(" @ ") + path;
-        } else {
-            c = url.toDisplayString();
-        }
+        c = Utils::niceFileNameWithPath(url);
     }
 
     setWindowFilePath(url.toString(QUrl::PreferLocalFile));
@@ -1211,26 +1217,26 @@ void KateMainWindow::readProperties(const KConfigGroup &config)
 
 void KateMainWindow::saveOpenRecent(KConfig *config)
 {
-    m_fileOpenRecent->saveEntries(KConfigGroup(config, "Recent Files"));
+    m_fileOpenRecent->saveEntries(KConfigGroup(config, QStringLiteral("Recent Files")));
 }
 
 void KateMainWindow::loadOpenRecent(const KConfig *config)
 {
-    m_fileOpenRecent->loadEntries(KConfigGroup(config, "Recent Files"));
+    m_fileOpenRecent->loadEntries(KConfigGroup(config, QStringLiteral("Recent Files")));
 }
 
 void KateMainWindow::saveGlobalProperties(KConfig *sessionConfig)
 {
     KateApp::self()->documentManager()->saveDocumentList(sessionConfig);
 
-    KConfigGroup cg(sessionConfig, "General");
+    KConfigGroup cg(sessionConfig, QStringLiteral("General"));
     cg.writeEntry("Last Session", KateApp::self()->sessionManager()->activeSession()->name());
 
     // save plugin config !!
     KateApp::self()->pluginManager()->writeConfig(sessionConfig);
 
     if (m_diagView) {
-        KConfigGroup cg(sessionConfig, "Kate Diagnostics");
+        KConfigGroup cg(sessionConfig, QStringLiteral("Kate Diagnostics"));
         m_diagView->writeSessionConfig(cg);
     }
 }
@@ -1285,7 +1291,7 @@ void KateMainWindow::slotUpdateBottomViewBar()
     }
 
     // always activate the current statusbar
-    Q_ASSERT(bs.statusBar()->parentWidget() == statusBarStackedWidget());
+    Q_ASSERT(bs.statusBar()->parent() == statusBarStackedWidget());
     statusBarStackedWidget()->setCurrentWidget(bs.statusBar());
 
     // hide or show the bar
@@ -1314,7 +1320,7 @@ void KateMainWindow::queueModifiedOnDisc(KTextEditor::Document *doc)
     bool modOnDisk = static_cast<uint>(docInfo->modifiedOnDisc);
 
     if (s_modOnHdDialog == nullptr && modOnDisk) {
-        QVector<KTextEditor::Document *> list;
+        QList<KTextEditor::Document *> list;
         list.append(doc);
 
         s_modOnHdDialog = new KateMwModOnHdDialog(list, this);
