@@ -8,7 +8,6 @@
 
 #pragma once
 
-#include "diffparams.h"
 #include "katemdi.h"
 #include "kateviewmanager.h"
 
@@ -155,10 +154,12 @@ private:
      */
     void setupImportantActions();
 
-    void setupMainWindow(KConfig *sconfig);
+    void setupMainWindow();
     void setupActions();
     bool queryClose() override;
 
+    void setupDiagnosticsView(KConfig *);
+
     /**
      * read some global options from katerc
      */
@@ -603,6 +604,8 @@ private Q_SLOTS:
     void slotDocumentCloseSelected(const QList<KTextEditor::Document *> &);
 
 private:
+    void ensureHamburgerBarSize();
+
     /**
      * Wrapper of main window for KTextEditor
      */
@@ -646,7 +649,7 @@ private:
     QWidget *m_bottomViewBarContainer = nullptr;
     KateContainerStackedLayout *m_bottomContainerStack = nullptr;
 
-    QVector<QString> m_lastUsedCmdBarActions;
+    QList<QString> m_lastUsedCmdBarActions;
 
     class BarState
     {
