@@ -10,8 +10,7 @@
 #include "katemdi.h"
 #include "kateapp.h"
 
-#include "katedebug.h"
-
+#include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KConfigGroup>
@@ -34,8 +33,6 @@
 #include <QTimer>
 #include <QVBoxLayout>
 
-#include <array>
-
 namespace KateMDI
 {
 // BEGIN TOGGLETOOLVIEWACTION
@@ -156,7 +153,7 @@ void GUIClient::registerToolView(ToolView *tv)
     auto shortcutsForActionName = [](const QString &aname) {
         QList<QKeySequence> shortcuts;
         KSharedConfigPtr cfg = KSharedConfig::openConfig();
-        const QString shortcutString = cfg->group("Shortcuts").readEntry(aname, QString());
+        const QString shortcutString = cfg->group(QStringLiteral("Shortcuts")).readEntry(aname, QString());
         const auto shortcutStrings = shortcutString.split(QLatin1Char(';'));
         for (const QString &shortcut : shortcutStrings) {
             shortcuts << QKeySequence::fromString(shortcut);
@@ -561,7 +558,7 @@ void Sidebar::readConfig()
     bool needsUpdate = false;
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup cgGeneral = KConfigGroup(config, "General");
+    KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
     const bool syncWithTabs = cgGeneral.readEntry("Sync section size with tab positions", false);
     if (syncWithTabs != m_syncWithTabs) {
         m_syncWithTabs = syncWithTabs;
@@ -1290,8 +1287,8 @@ void Sidebar::saveSession(KConfigGroup &config)
 
 // BEGIN MAIN WINDOW
 
-MainWindow::MainWindow(QWidget *parentWidget)
-    : KParts::MainWindow(parentWidget, Qt::Window)
+MainWindow::MainWindow(QWidget *parent)
+    : KParts::MainWindow(parent, Qt::Window)
     , m_guiClient(new GUIClient(this))
 {
     // central frame for all stuff
@@ -1653,6 +1650,16 @@ void MainWindow::saveSession(KConfigGroup &config)
     }
 }
 
+QWidget *MainWindow::createContainer(QWidget *parent, int index, const QDomElement &element, QAction *&containerAction)
+{
+    // ensure we don't have toolbar accelerators that clash with other stuff
+    QWidget *createdContainer = KParts::MainWindow::createContainer(parent, index, element, containerAction);
+    if (element.tagName() == QLatin1String("ToolBar")) {
+        KAcceleratorManager::setNoAccel(createdContainer);
+    }
+    return createdContainer;
+}
+
 // END MAIN WINDOW
 
 } // namespace KateMDI
