@@ -8,6 +8,7 @@
 
 #include "diffwidget.h"
 #include "gitprocess.h"
+#include "hostprocess.h"
 #include "kateapp.h"
 #include "katedocmanager.h"
 #include "katemainwindow.h"
@@ -46,7 +47,7 @@ public:
     QPointer<KTextEditor::Document> document;
 };
 
-KateMwModOnHdDialog::KateMwModOnHdDialog(const QVector<KTextEditor::Document *> &docs, QWidget *parent, const char *name)
+KateMwModOnHdDialog::KateMwModOnHdDialog(const QList<KTextEditor::Document *> &docs, QWidget *parent, const char *name)
     : QDialog(parent)
     , m_blockAddDocument(false)
 {
@@ -182,18 +183,9 @@ void KateMwModOnHdDialog::handleSelected(int action)
         }
 
         if (item->checkState(0) == Qt::Checked) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             KTextEditor::Document::ModifiedOnDiskReason reason = docInfo->modifiedOnDiscReason;
             bool success = true;
             item->document->setModifiedOnDisk(KTextEditor::Document::OnDiskUnmodified);
-#else
-            KTextEditor::ModificationInterface::ModifiedOnDiskReason reason = docInfo->modifiedOnDiscReason;
-            bool success = true;
-
-            if (KTextEditor::ModificationInterface *iface = qobject_cast<KTextEditor::ModificationInterface *>(item->document)) {
-                iface->setModifiedOnDisk(KTextEditor::ModificationInterface::OnDiskUnmodified);
-            }
-#endif
 
             switch (action) {
             case Overwrite:
@@ -214,13 +206,7 @@ void KateMwModOnHdDialog::handleSelected(int action)
             if (success) {
                 itemsToDelete.append(item);
             } else {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                 item->document->setModifiedOnDisk(reason);
-#else
-                if (KTextEditor::ModificationInterface *iface = qobject_cast<KTextEditor::ModificationInterface *>(item->document)) {
-                    iface->setModifiedOnDisk(reason);
-                }
-#endif
             }
         }
     }
@@ -248,11 +234,7 @@ void KateMwModOnHdDialog::slotSelectionChanged(QTreeWidgetItem *current, QTreeWi
     if (currentDocItem && currentDocItem->document) {
         auto *docInfo = KateApp::self()->documentManager()->documentInfo(currentDocItem->document);
         // set the diff button enabled
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         btnDiff->setEnabled(docInfo && docInfo->modifiedOnDiscReason != KTextEditor::Document::OnDiskDeleted);
-#else
-        btnDiff->setEnabled(docInfo && docInfo->modifiedOnDiscReason != KTextEditor::ModificationInterface::OnDiskDeleted);
-#endif
     }
 }
 
@@ -295,15 +277,9 @@ void KateMwModOnHdDialog::slotDiff()
     }
 
     // don't try to diff a deleted file
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (docInfo->modifiedOnDiscReason == KTextEditor::Document::OnDiskDeleted) {
         return;
     }
-#else
-    if (docInfo->modifiedOnDiscReason == KTextEditor::ModificationInterface::OnDiskDeleted) {
-        return;
-    }
-#endif
 
     auto f = new QTemporaryFile(this);
     f->open();
@@ -348,7 +324,7 @@ void KateMwModOnHdDialog::slotGitDiffDone(QProcess *p, KTextEditor::Document *do
         QString t = QFileInfo(doc->url().toLocalFile()).fileName() + i18n("[NEW]");
         params.tabTitle = s + QStringLiteral("..") + t;
         params.workingDir = p->workingDirectory();
-        auto mw = static_cast<KateMainWindow *>(parentWidget());
+        auto mw = static_cast<KateMainWindow *>(parent());
         DiffWidgetManager::openDiff(out, params, mw->wrapper());
     }
 }
