@@ -54,13 +54,13 @@ KateTabBar::KateTabBar(QWidget *parent)
 void KateTabBar::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup cgGeneral = KConfigGroup(config, "General");
+    KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
 
     // 0 == unlimited, normalized other inputs
     const int tabCountLimit = std::max(cgGeneral.readEntry("Tabbar Tab Limit", 0), 0);
     if (m_tabCountLimit != tabCountLimit) {
         m_tabCountLimit = tabCountLimit;
-        const QVector<DocOrWidget> docList = documentList();
+        const QList<DocOrWidget> docList = documentList();
         if (m_tabCountLimit > 0 && docList.count() > m_tabCountLimit) {
             // close N least used tabs
             QMap<quint64, DocOrWidget> lruDocs;
@@ -198,7 +198,7 @@ void KateTabBar::mouseMoveEvent(QMouseEvent *event)
     // One disadvantage of the current approach is that the user
     // might not know that kate's tabs can be dragged to other
     // places, unless they drag it really far away
-    auto viewSpace = qobject_cast<KateViewSpace *>(parentWidget());
+    auto viewSpace = qobject_cast<KateViewSpace *>(parent());
     const auto viewspaceRect = viewSpace->rect();
     QRect viewspaceRectTopArea = viewspaceRect;
     viewspaceRectTopArea.setTop(viewspaceRect.top() - 40);
@@ -235,11 +235,7 @@ void KateTabBar::mouseMoveEvent(QMouseEvent *event)
 
     // For some reason initStyleOption with tabIdx directly
     // wasn't working, so manually set some stuff
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QStyleOptionTabV4 opt;
-#else
     QStyleOptionTab opt;
-#endif
     opt.text = tabText(tab);
     opt.icon = tabIcon(tab);
     opt.iconSize = iconSize();
@@ -485,9 +481,9 @@ void KateTabBar::tabInserted(int idx)
     m_beingAdded.clear();
 }
 
-QVector<DocOrWidget> KateTabBar::documentList() const
+QList<DocOrWidget> KateTabBar::documentList() const
 {
-    QVector<DocOrWidget> result;
+    QList<DocOrWidget> result;
     result.reserve(count());
     for (int idx = 0; idx < count(); idx++) {
         QVariant data = tabData(idx);
