@@ -9,6 +9,7 @@
 #include "ktexteditor_utils.h"
 
 #include <KTextEditor/Document>
+#include <KTextEditor/Editor>
 #include <KTextEditor/View>
 
 #include <KColorScheme>
@@ -151,7 +152,7 @@ protected:
         if (e->type() == QEvent::MouseButtonPress) {
             QMouseEvent *me = static_cast<QMouseEvent *>(e);
             if (me->button() == Qt::LeftButton) {
-                const QModelIndex idx = m_itemView.indexAt(m_itemView.viewport()->mapFromGlobal(me->globalPos()));
+                const QModelIndex idx = m_itemView.indexAt(m_itemView.viewport()->mapFromGlobal(me->globalPosition().toPoint()));
                 if (!idx.isValid()) {
                     return QWidget::eventFilter(o, me);
                 }
@@ -292,7 +293,7 @@ public:
 
         connect(&m_list, &FilterableListView::returnPressed, this, &DirFilesList::onClicked);
         connect(&m_list, &FilterableListView::clicked, this, &DirFilesList::onClicked);
-        connect(qApp, &QApplication::paletteChanged, this, &DirFilesList::updatePalette, Qt::QueuedConnection);
+        connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, &DirFilesList::updatePalette, Qt::QueuedConnection);
     }
 
     void updatePalette()
@@ -399,7 +400,7 @@ public:
 
         connect(&m_tree, &FilterableTreeView::clicked, this, &SymbolsTreeView::onClicked);
         connect(&m_tree, &FilterableTreeView::returnPressed, this, &SymbolsTreeView::onClicked);
-        connect(qApp, &QApplication::paletteChanged, this, &SymbolsTreeView::updatePalette, Qt::QueuedConnection);
+        connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, &SymbolsTreeView::updatePalette, Qt::QueuedConnection);
     }
 
     void updatePalette()
@@ -582,11 +583,11 @@ public:
         setTextElideMode(Qt::ElideNone);
         setSpacing(0);
 
-        connect(qApp, &QApplication::paletteChanged, this, &BreadCrumbView::updatePalette, Qt::QueuedConnection);
+        connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, &BreadCrumbView::updatePalette, Qt::QueuedConnection);
         updatePalette();
 
         auto onConfigChanged = [this] {
-            KConfigGroup cg(KSharedConfig::openConfig(), "General");
+            KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("General"));
             auto v = cg.readEntry("Show Symbol In Navigation Bar", true);
             if (v != m_showSymbolCrumb) {
                 m_showSymbolCrumb = v;
@@ -602,7 +603,7 @@ public:
     void updatePalette()
     {
         auto pal = palette();
-        pal.setBrush(QPalette::Base, parentWidget()->palette().window());
+        pal.setBrush(QPalette::Base, qobject_cast<QWidget *>(parent())->palette().window());
         auto textColor = pal.text().color();
         textColor = textColor.lightness() > 127 ? textColor.darker(150) : textColor.lighter(150);
         pal.setBrush(QPalette::Inactive, QPalette::Text, textColor);
@@ -894,12 +895,8 @@ public:
     {
         const auto rowCount = m_model.rowCount();
         int w = 0;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-        QStyleOptionViewItem opt = viewOptions();
-#else
         QStyleOptionViewItem opt;
         initViewItemOption(&opt);
-#endif
         auto delegate = itemDelegate();
         for (int i = 0; i < rowCount; ++i) {
             w += delegate->sizeHint(opt, m_model.index(i, 0)).width();
@@ -932,14 +929,14 @@ private:
         }
     }
 
-    static QVector<DirNamePath> splittedUrl(const QString &base, const QString &s)
+    static QList<DirNamePath> splittedUrl(const QString &base, const QString &s)
     {
         QDir dir(s);
         const QString fileName = dir.dirName();
         dir.cdUp();
         const QString path = dir.absolutePath();
 
-        QVector<DirNamePath> dirsList;
+        QList<DirNamePath> dirsList;
         dirsList << DirNamePath{fileName, path};
 
         // arrived at base?
@@ -1033,8 +1030,8 @@ public:
         });
 
         connect(
-            qApp,
-            &QApplication::paletteChanged,
+            KTextEditor::Editor::instance(),
+            &KTextEditor::Editor::configChanged,
             this,
             [this] {
                 m_sepPixmap = QPixmap();
@@ -1086,11 +1083,7 @@ protected:
         QWidget::leaveEvent(e);
     }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    void enterEvent(QEvent *e) override
-#else
     void enterEvent(QEnterEvent *e) override
-#endif
     {
         m_fullPathHideTimer.stop();
         QWidget::leaveEvent(e);
@@ -1207,7 +1200,7 @@ void KateUrlBar::setupLayout()
         m_untitledDocLabel->setPalette(pal);
     };
     updatePalette();
-    connect(qApp, &QApplication::paletteChanged, this, updatePalette, Qt::QueuedConnection);
+    connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, updatePalette, Qt::QueuedConnection);
 }
 
 void KateUrlBar::onViewChanged(KTextEditor::View *v)
