@@ -9,7 +9,6 @@
 
 #include "diffwidget.h"
 #include "kateapp.h"
-#include "katedebug.h"
 #include "katedocmanager.h"
 #include "katefileactions.h"
 #include "katemainwindow.h"
@@ -114,6 +113,15 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     m_split->addAction(m_viewManager->mainWindow()->actionCollection()->action(QStringLiteral("view_hide_others")));
     m_split->setToolTip(i18n("Split View"));
     m_split->setWhatsThis(i18n("Control view space splitting"));
+
+    //  add action for Synchronous scrolling. This needs to be one per ViewSpace instance
+    m_toggleSynchronisedScrolling = new KToggleAction(i18n("S&ynchronize Scrolling"), this);
+    m_toggleSynchronisedScrolling->setIcon(QIcon::fromTheme(QStringLiteral("view-sync")));
+    m_toggleSynchronisedScrolling->setWhatsThis(i18n("Synchronize Scrolling of this split-view with other synchronized split-views"));
+    m_split->addAction(m_toggleSynchronisedScrolling);
+    connect(m_toggleSynchronisedScrolling, &QAction::triggered, m_viewManager, &KateViewManager::slotSynchroniseScrolling);
+
+    m_split->installEventFilter(this); // on click, active this view space
     hLayout->addWidget(m_split);
 
     layout->addLayout(hLayout);
@@ -184,7 +192,7 @@ void KateViewSpace::readConfig()
 {
     // get tab config
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup cgGeneral = KConfigGroup(config, "General");
+    KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
     m_autoHideTabBar = cgGeneral.readEntry("Auto Hide Tabs", KateApp::isKWrite());
 
     // init tab bar
@@ -1023,7 +1031,7 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
     auto *doc = docOrWidget.doc();
 
     auto addActionFromCollection = [this](QMenu *menu, const char *action_name) {
-        QAction *action = m_viewManager->mainWindow()->action(action_name);
+        QAction *action = m_viewManager->mainWindow()->action(QLatin1StringView(action_name));
         return menu->addAction(action->icon(), action->text());
     };
 
