@@ -146,7 +146,7 @@ WelcomeView::WelcomeView(KateViewManager *viewManager, QWidget *parent)
     }
 
     static const char showForNewWindowKey[] = "Show welcome view for new window";
-    KConfigGroup configGroup = KSharedConfig::openConfig()->group("General");
+    KConfigGroup configGroup = KSharedConfig::openConfig()->group(QStringLiteral("General"));
     checkBoxShowForNewWindow->setChecked(configGroup.readEntry(showForNewWindowKey, true));
     connect(checkBoxShowForNewWindow, &QCheckBox::toggled, this, [configGroup](bool checked) mutable {
         configGroup.writeEntry(showForNewWindowKey, checked);
@@ -284,7 +284,7 @@ void WelcomeView::onRecentItemsContextMenuRequested(const QPoint &pos)
 
 void WelcomeView::updateButtons()
 {
-    QVector<QPushButton *> buttons{buttonNewFile, buttonOpenFile, buttonOpenFolder};
+    QList<QPushButton *> buttons{buttonNewFile, buttonOpenFile, buttonOpenFolder};
     if (KateApp::isKate()) {
         buttons << buttonNewSession << buttonManageSessions;
     }
